---@meta

---Tags and options configured here will be used by the Add Tags command to add tags to struct fields. If promptForTags is true, then user will be prompted for tags and options. By default, json tags are added.
---
---```lua
---default = {
---  options = "json=omitempty",
---  promptForTags = false,
---  tags = "json",
---  template = "",
---  transform = "snakecase"
---}
---```
---@class _.lspconfig.settings.gopls.Go.AddTags
---Comma separated tag=options pairs to be used by Go: Add Tags command
---
---```lua
---default = "json=omitempty"
---```
---@field options? string
---If true, Go: Add Tags command will prompt the user to provide tags, options, transform values instead of using the configured values
---@field promptForTags? boolean
---Comma separated tags to be used by Go: Add Tags command
---
---```lua
---default = "json"
---```
---@field tags? string
---Custom format used by Go: Add Tags command for the tag value to be applied
---
---```lua
---default = ""
---```
---@field template? string
---Transformation rule used by Go: Add Tags command to add tags
---
---```lua
---default = "snakecase"
---```
---@field transform? "snakecase" | "camelcase" | "lispcase" | "pascalcase" | "keep"

---Alternate tools or alternate paths for the same tools used by the Go extension. Provide either absolute path or the name of the binary in GOPATH/bin, GOROOT/bin or PATH. Useful when you want to use wrapper script for the Go tools.
---
---```lua
---default = {}
---```
---@class _.lspconfig.settings.gopls.Go.AlternateTools
---Custom formatter to use instead of the language server. This should be used with the `custom` option in `#go.formatTool#`.
---
---```lua
---default = ""
---```
---@field customFormatter? string
---Alternate tool to use instead of the dlv binary or alternate path to use for the dlv binary.
---
---```lua
---default = "dlv"
---```
---@field dlv? string
---Alternate tool to use instead of the go binary or alternate path to use for the go binary.
---
---```lua
---default = "go"
---```
---@field go? string
---Alternate tool to use instead of the gopls binary or alternate path to use for the gopls binary.
---
---```lua
---default = "gopls"
---```
---@field gopls? string

---This option lets you choose the way to display code coverage. Choose either to highlight the complete line or to show a decorator in the gutter. You can customize the colors and borders for the former and the style for the latter.
---
---```lua
---default = {
---  coveredBorderColor = "rgba(64,128,128,0.5)",
---  coveredGutterStyle = "blockblue",
---  coveredHighlightColor = "rgba(64,128,128,0.5)",
---  type = "highlight",
---  uncoveredBorderColor = "rgba(128,64,64,0.25)",
---  uncoveredGutterStyle = "slashyellow",
---  uncoveredHighlightColor = "rgba(128,64,64,0.25)"
---}
---```
---@class _.lspconfig.settings.gopls.Go.CoverageDecorator
---Color to use for the border of covered code.
---@field coveredBorderColor? string
---Gutter style to indicate covered code.
---@field coveredGutterStyle? "blockblue" | "blockred" | "blockgreen" | "blockyellow" | "slashred" | "slashgreen" | "slashblue" | "slashyellow" | "verticalred" | "verticalgreen" | "verticalblue" | "verticalyellow"
---Color in the rgba format to use to highlight covered code.
---@field coveredHighlightColor? string
---@field type? "highlight" | "gutter"
---Color to use for the border of uncovered code.
---@field uncoveredBorderColor? string
---Gutter style to indicate covered code.
---@field uncoveredGutterStyle? "blockblue" | "blockred" | "blockgreen" | "blockyellow" | "slashred" | "slashgreen" | "slashblue" | "slashyellow" | "verticalred" | "verticalgreen" | "verticalblue" | "verticalyellow"
---Color in the rgba format to use to highlight uncovered code.
---@field uncoveredHighlightColor? string

---LoadConfig describes to delve, how to load values from target's memory. Ignored by 'dlv-dap'.
---
---```lua
---default = {
---  followPointers = true,
---  maxArrayValues = 64,
---  maxStringLen = 64,
---  maxStructFields = -1,
---  maxVariableRecurse = 1
---}
---```
---@class _.lspconfig.settings.gopls.Go.DelveConfig.DlvLoadConfig
---FollowPointers requests pointers to be automatically dereferenced
---
---```lua
---default = true
---```
---@field followPointers? boolean
---MaxArrayValues is the maximum number of elements read from an array, a slice or a map
---
---```lua
---default = 64
---```
---@field maxArrayValues? number
---MaxStringLen is the maximum number of bytes read from a string
---
---```lua
---default = 64
---```
---@field maxStringLen? number
---MaxStructFields is the maximum number of fields read from a struct, -1 will read all fields
---
---```lua
---default = -1
---```
---@field maxStructFields? number
---MaxVariableRecurse is how far to recurse when evaluating nested types
---
---```lua
---default = 1
---```
---@field maxVariableRecurse? number

---Delve settings that applies to all debugging sessions. Debug configuration in the launch.json file will override these values.
---
---```lua
---default = {}
---```
---@class _.lspconfig.settings.gopls.Go.DelveConfig
---Delve Api Version to use. Default value is 2. This applies only when using the 'legacy' debug adapter.
---
---```lua
---default = 2
---```
---@field apiVersion? 1 | 2
---Select which debug adapter to use by default. This is also used for choosing which debug adapter to use when no launch.json is present and with codelenses.
---
---```lua
---default = "dlv-dap"
---```
---@field debugAdapter? "legacy" | "dlv-dap"
---Extra flags for `dlv`. See `dlv help` for the full list of supported. Flags such as `--log-output`, `--log`, `--log-dest`, `--api-version`, `--output`, `--backend` already have corresponding properties in the debug configuration, and flags such as `--listen` and `--headless` are used internally. If they are specified in `dlvFlags`, they may be ignored or cause an error.
---
---```lua
---default = {}
---```
---@field dlvFlags? string[]
---LoadConfig describes to delve, how to load values from target's memory. Ignored by 'dlv-dap'.
---
---```lua
---default = {
---  followPointers = true,
---  maxArrayValues = 64,
---  maxStringLen = 64,
---  maxStructFields = -1,
---  maxVariableRecurse = 1
---}
---```
---@field dlvLoadConfig? _.lspconfig.settings.gopls.Go.DelveConfig.DlvLoadConfig
---Boolean value to indicate whether system goroutines should be hidden from call stack view.
---@field hideSystemGoroutines? boolean
---Comma separated list of components that should produce debug output. Maps to dlv's `--log-output` flag. Check `dlv log` for details.
---
---```lua
---default = "debugger"
---```
---@field logOutput? "debugger" | "gdbwire" | "lldbout" | "debuglineerr" | "rpc" | "dap"
---Boolean value to indicate whether global package variables should be shown in the variables pane or not.
---@field showGlobalVariables? boolean
---Show log output from the delve debugger. Maps to dlv's `--log` flag.
---@field showLog? boolean
---Boolean value to indicate whether register variables should be shown in the variables pane or not.
---@field showRegisters? boolean
---An array of mappings from a local path to the remote path that is used by the debuggee. The debug adapter will replace the local path with the remote path in all of the calls. Overridden by `remotePath` (in attach request).
---
---```lua
---default = {}
---```
---@field substitutePath? table[]

---@class _.lspconfig.settings.gopls.Go.Diagnostic
---(Experimental) vulncheck enables vulnerability scanning.
---
---
---```lua
---default = "Prompt"
---```
---@field vulncheck? "Imports" | "Off" | "Prompt"

---Experimental Feature: Enable/Disable entries from the context menu in the editor.
---
---```lua
---default = {
---  addImport = true,
---  addTags = true,
---  benchmarkAtCursor = false,
---  compilerDetails = false,
---  debugTestAtCursor = true,
---  fillStruct = false,
---  generateTestForFile = false,
---  generateTestForFunction = true,
---  generateTestForPackage = false,
---  playground = true,
---  removeTags = false,
---  testAtCursor = true,
---  testCoverage = true,
---  testFile = false,
---  testPackage = false,
---  toggleTestFile = true
---}
---```
---@class _.lspconfig.settings.gopls.Go.EditorContextMenuCommands
---If true, adds command to import a package to the editor context menu
---
---```lua
---default = true
---```
---@field addImport? boolean
---If true, adds command to add configured tags from struct fields to the editor context menu
---
---```lua
---default = true
---```
---@field addTags? boolean
---If true, adds command to benchmark the test under the cursor to the editor context menu
---@field benchmarkAtCursor? boolean
---If true, adds command to show compiler optimization details under the cursor to the editor context menu
---@field compilerDetails? boolean
---If true, adds command to debug the test under the cursor to the editor context menu
---@field debugTestAtCursor? boolean
---If true, adds command to fill struct literal with default values to the editor context menu
---
---```lua
---default = true
---```
---@field fillStruct? boolean
---If true, adds command to generate unit tests for current file to the editor context menu
---
---```lua
---default = true
---```
---@field generateTestForFile? boolean
---If true, adds command to generate unit tests for function under the cursor to the editor context menu
---
---```lua
---default = true
---```
---@field generateTestForFunction? boolean
---If true, adds command to generate unit tests for current package to the editor context menu
---
---```lua
---default = true
---```
---@field generateTestForPackage? boolean
---If true, adds command to upload the current file or selection to the Go Playground
---
---```lua
---default = true
---```
---@field playground? boolean
---If true, adds command to remove configured tags from struct fields to the editor context menu
---
---```lua
---default = true
---```
---@field removeTags? boolean
---If true, adds command to run the test under the cursor to the editor context menu
---@field testAtCursor? boolean
---If true, adds command to run test coverage to the editor context menu
---
---```lua
---default = true
---```
---@field testCoverage? boolean
---If true, adds command to run all tests in the current file to the editor context menu
---
---```lua
---default = true
---```
---@field testFile? boolean
---If true, adds command to run all tests in the current package to the editor context menu
---
---```lua
---default = true
---```
---@field testPackage? boolean
---If true, adds command to toggle between a Go file and its test file to the editor context menu
---
---```lua
---default = true
---```
---@field toggleTestFile? boolean

---Feature level setting to enable/disable code lens for references and run/debug tests
---
---```lua
---default = {
---  runtest = true
---}
---```
---@class _.lspconfig.settings.gopls.Go.EnableCodeLens
---If true, enables code lens for running and debugging tests
---
---```lua
---default = true
---```
---@field runtest? boolean

---Disable experimental features. These features are only available in the pre-release version.
---
---```lua
---default = {
---  testExplorer = true
---}
---```
---@class _.lspconfig.settings.gopls.Go.Experiments
---Prefer the experimental test explorer
---
---```lua
---default = true
---```
---@field testExplorer? boolean

---@class _.lspconfig.settings.gopls.Go.InlayHints
---`"assignVariableTypes"` controls inlay hints for variable types in assign statements:
---```go
---	i« int», j« int» := 0, len(r)-1
---```
---
---@field assignVariableTypes? boolean
---`"compositeLiteralFields"` inlay hints for composite literal field names:
---```go
---	Point2D{«X: »1, «Y: »2}
---
---	Outer{«Embedded.»Field: 0}
---```
---
---@field compositeLiteralFields? boolean
---`"compositeLiteralTypes"` controls inlay hints for composite literal types:
---```go
---	for _, c := range []struct {
---		in, want string
---	}{
---		«struct{ in string; want string }»{"Hello, world", "dlrow ,olleH"},
---	}
---```
---
---@field compositeLiteralTypes? boolean
---`"constantValues"` controls inlay hints for constant values:
---```go
---	const (
---		KindNone   Kind = iota« = 0»
---		KindPrint«  = 1»
---		KindPrintf« = 2»
---		KindErrorf« = 3»
---	)
---```
---
---@field constantValues? boolean
---`"functionTypeParameters"` inlay hints for implicit type parameters on generic functions:
---```go
---	myFoo«[int, string]»(1, "hello")
---```
---
---@field functionTypeParameters? boolean
---`"ignoredError"` inlay hints for implicitly discarded errors:
---```go
---	f.Close()« // ignore error»
---```
---This check inserts an `// ignore error` hint following any
---statement that is a function call whose error result is
---implicitly ignored.
---
---To suppress the hint, write an actual comment containing
---"ignore error" following the call statement, or explicitly
---assign the result to a blank variable. A handful of common
---functions such as `fmt.Println` are excluded from the
---check.
---
---@field ignoredError? boolean
---`"parameterNames"` controls inlay hints for parameter names:
---```go
---	parseInt(« str: » "123", « radix: » 8)
---```
---
---@field parameterNames? boolean
---`"rangeVariableTypes"` controls inlay hints for variable types in range statements:
---```go
---	for k« int», v« string» := range []string{} {
---		fmt.Println(k, v)
---	}
---```
---
---@field rangeVariableTypes? boolean

---@class _.lspconfig.settings.gopls.Go.Logging
---@field level? string

---The flags configured here will be passed through to command `goplay`
---
---```lua
---default = {
---  openbrowser = true,
---  run = true,
---  share = true
---}
---```
---@class _.lspconfig.settings.gopls.Go.Playground
---Whether to open the created Go Playground in the default browser
---
---```lua
---default = true
---```
---@field openbrowser? boolean
---Whether to run the created Go Playground after creation
---
---```lua
---default = true
---```
---@field run? boolean
---Whether to make the created Go Playground shareable
---
---```lua
---default = true
---```
---@field share? boolean

---Tags and options configured here will be used by the Remove Tags command to remove tags to struct fields. If promptForTags is true, then user will be prompted for tags and options. By default, all tags and options will be removed.
---
---```lua
---default = {
---  options = "",
---  promptForTags = false,
---  tags = ""
---}
---```
---@class _.lspconfig.settings.gopls.Go.RemoveTags
---Comma separated tag=options pairs to be used by Go: Remove Tags command
---
---```lua
---default = "json=omitempty"
---```
---@field options? string
---If true, Go: Remove Tags command will prompt the user to provide tags and options instead of using the configured values
---@field promptForTags? boolean
---Comma separated tags to be used by Go: Remove Tags command
---
---```lua
---default = "json"
---```
---@field tags? string

---@class _.lspconfig.settings.gopls.Go.Survey
---Prompt for surveys, including the gopls survey and the Go developer survey.
---
---```lua
---default = true
---```
---@field prompt? boolean

---@class _.lspconfig.settings.gopls.Go.Tasks
---enable the default go build/test task provider.
---
---```lua
---default = true
---```
---@field provideDefault? boolean

---@class _.lspconfig.settings.gopls.Go.Terminal
---Apply the Go & PATH environment variables used by the extension to all integrated terminals.
---
---```lua
---default = true
---```
---@field activateEnvironment? boolean

---@class _.lspconfig.settings.gopls.Go.TestExplorer
---Run benchmarks when running all tests in a file or folder.
---@field alwaysRunBenchmarks? boolean
---Concatenate all test log messages for a given location into a single message.
---
---```lua
---default = true
---```
---@field concatenateMessages? boolean
---Enable the Go test explorer
---
---```lua
---default = true
---```
---@field enable? boolean
---Present packages in the test explorer flat or nested.
---
---```lua
---default = "flat"
---```
---@field packageDisplayMode? "flat" | "nested"
---Set the source location of dynamically discovered subtests to the location of the containing function. As a result, dynamically discovered subtests will be added to the gutter test widget of the containing function.
---@field showDynamicSubtestsInEditor? boolean
---Open the test output terminal when a test run is started.
---
---```lua
---default = true
---```
---@field showOutput? boolean

---@class _.lspconfig.settings.gopls.Go.ToolsManagement
---Automatically update the tools used by the extension, without prompting the user.
---@field autoUpdate? boolean
---Specify whether to prompt about new versions of Go and the Go tools (currently, only `gopls`) the extension depends on
---
---```lua
---default = "proxy"
---```
---@field checkForUpdates? "proxy" | "local" | "off"
---The path to the `go` binary used to install the Go tools. If it's empty, the same `go` binary chosen for the project will be used for tool installation.
---
---```lua
---default = ""
---```
---@field go? string

---@class _.lspconfig.settings.gopls.Go.Trace
---Trace the communication between VS Code and the Go language server.
---
---```lua
---default = "off"
---```
---@field server? "off" | "messages" | "verbose"

---@class _.lspconfig.settings.gopls.Go
---Tags and options configured here will be used by the Add Tags command to add tags to struct fields. If promptForTags is true, then user will be prompted for tags and options. By default, json tags are added.
---
---```lua
---default = {
---  options = "json=omitempty",
---  promptForTags = false,
---  tags = "json",
---  template = "",
---  transform = "snakecase"
---}
---```
---@field addTags? _.lspconfig.settings.gopls.Go.AddTags
---Alternate tools or alternate paths for the same tools used by the Go extension. Provide either absolute path or the name of the binary in GOPATH/bin, GOROOT/bin or PATH. Useful when you want to use wrapper script for the Go tools.
---
---```lua
---default = {}
---```
---@field alternateTools? _.lspconfig.settings.gopls.Go.AlternateTools
---Flags to `go build`/`go test` used during build-on-save or running tests. (e.g. ["-ldflags='-s'"]) This is propagated to the language server if `gopls.build.buildFlags` is not specified.
---
---```lua
---default = {}
---```
---@field buildFlags? string[]
---Compiles code on file save using 'go build' or 'go test -c'. Not applicable when using the language server.
---
---```lua
---default = "package"
---```
---@field buildOnSave? "package" | "workspace" | "off"
---The Go build tags to use for all commands, that support a `-tags '...'` argument. When running tests, go.testTags will be used instead if it was set. This is propagated to the language server if `gopls.build.buildFlags` is not specified.
---
---```lua
---default = ""
---```
---@field buildTags? string
---When generating code coverage, the value for -covermode. 'default' is the default value chosen by the 'go test' command.
---
---```lua
---default = "default"
---```
---@field coverMode? "default" | "set" | "count" | "atomic"
---If true, runs 'go test -coverprofile' on save and shows test coverage.
---@field coverOnSave? boolean
---If true, shows test coverage when Go: Test Function at cursor command is run.
---@field coverOnSingleTest? boolean
---If true, shows test coverage when Go: Test Single File command is run.
---@field coverOnSingleTestFile? boolean
---If true, shows test coverage when Go: Test Package command is run.
---
---```lua
---default = true
---```
---@field coverOnTestPackage? boolean
---When generating code coverage, should counts be shown as --374--
---@field coverShowCounts? boolean
---This option lets you choose the way to display code coverage. Choose either to highlight the complete line or to show a decorator in the gutter. You can customize the colors and borders for the former and the style for the latter.
---
---```lua
---default = {
---  coveredBorderColor = "rgba(64,128,128,0.5)",
---  coveredGutterStyle = "blockblue",
---  coveredHighlightColor = "rgba(64,128,128,0.5)",
---  type = "highlight",
---  uncoveredBorderColor = "rgba(128,64,64,0.25)",
---  uncoveredGutterStyle = "slashyellow",
---  uncoveredHighlightColor = "rgba(128,64,64,0.25)"
---}
---```
---@field coverageDecorator? _.lspconfig.settings.gopls.Go.CoverageDecorator
---Use these options to control whether only covered or only uncovered code or both should be highlighted after running test coverage
---
---```lua
---default = "showBothCoveredAndUncoveredCode"
---```
---@field coverageOptions? "showCoveredCodeOnly" | "showUncoveredCodeOnly" | "showBothCoveredAndUncoveredCode"
---Delve settings that applies to all debugging sessions. Debug configuration in the launch.json file will override these values.
---
---```lua
---default = {}
---```
---@field delveConfig? _.lspconfig.settings.gopls.Go.DelveConfig
---@field diagnostic? _.lspconfig.settings.gopls.Go.Diagnostic
---If true, tests will not run concurrently. When a new test run is started, the previous will be cancelled.
---@field disableConcurrentTests? boolean
---Experimental Feature: Enable/Disable entries from the context menu in the editor.
---
---```lua
---default = {
---  addImport = true,
---  addTags = true,
---  benchmarkAtCursor = false,
---  compilerDetails = false,
---  debugTestAtCursor = true,
---  fillStruct = false,
---  generateTestForFile = false,
---  generateTestForFunction = true,
---  generateTestForPackage = false,
---  playground = true,
---  removeTags = false,
---  testAtCursor = true,
---  testCoverage = true,
---  testFile = false,
---  testPackage = false,
---  toggleTestFile = true
---}
---```
---@field editorContextMenuCommands? _.lspconfig.settings.gopls.Go.EditorContextMenuCommands
---Feature level setting to enable/disable code lens for references and run/debug tests
---
---```lua
---default = {
---  runtest = true
---}
---```
---@field enableCodeLens? _.lspconfig.settings.gopls.Go.EnableCodeLens
---Disable experimental features. These features are only available in the pre-release version.
---
---```lua
---default = {
---  testExplorer = true
---}
---```
---@field experiments? _.lspconfig.settings.gopls.Go.Experiments
---Flags to pass to format tool (e.g. ["-s"]). Not applicable when using the language server.
---
---```lua
---default = {}
---```
---@field formatFlags? string[]
---Specifies the tool for formatting Go code. The default is `default`, which uses the language server `gopls` as formatting provider. To configure gopls's formatting, see the 'gopls.formatting' settings. When a specific tool (e.g., `gofmt`, `goimports`) is selected, the extension will run it instead.
---
---```lua
---default = "default"
---```
---@field formatTool? "default" | "gofmt" | "goimports" | "goformat" | "gofumpt" | "custom"
---Additional command line flags to pass to `gotests` for generating tests.
---
---```lua
---default = {}
---```
---@field generateTestsFlags? string[]
---Specify GOPATH here to override the one that is set as environment variable. The inferred GOPATH from workspace root overrides this, if go.inferGopath is set to true.
---@field gopath? string
---Specifies the GOROOT to use when no environment variable is set.
---@field goroot? string
---Infer GOPATH from the workspace root. This is ignored when using Go Modules.
---@field inferGopath? boolean
---@field inlayHints? _.lspconfig.settings.gopls.Go.InlayHints
---If true, then `-i` flag will be passed to `go build` everytime the code is compiled. Since Go 1.10, setting this may be unnecessary unless you are in GOPATH mode and do not use the language server.
---@field installDependenciesWhenBuilding? boolean
---Flags like -rpc.trace and -logfile to be used while running the language server.
---
---```lua
---default = {}
---```
---@field languageServerFlags? any[]
---Flags to pass to Lint tool (e.g. ["-min_confidence=.8"])
---
---```lua
---default = {}
---```
---@field lintFlags? string[]
---Lints code on file save using the configured Lint tool. Options are 'file', 'package', 'workspace' or 'off'.
---
---```lua
---default = "package"
---```
---@field lintOnSave? "file" | "package" | "workspace" | "off"
---Specifies an additional client-side linting tool that should be run by the Go extension. By default (unset), no additional linter is run. This feature is additional to diagnostics reported by the language server, gopls. Since Gopls incorporates the entire staticcheck analyzer suite, it is typically unnecessary to run the staticcheck tool as well. To configure gopls's linting, see the 'gopls.ui.diagnostic' settings.
---@field lintTool? "staticcheck" | "golint" | "golangci-lint" | "golangci-lint-v2" | "revive"
---@field logging? _.lspconfig.settings.gopls.Go.Logging
---The flags configured here will be passed through to command `goplay`
---
---```lua
---default = {
---  openbrowser = true,
---  run = true,
---  share = true
---}
---```
---@field playground? _.lspconfig.settings.gopls.Go.Playground
---Tags and options configured here will be used by the Remove Tags command to remove tags to struct fields. If promptForTags is true, then user will be prompted for tags and options. By default, all tags and options will be removed.
---
---```lua
---default = {
---  options = "",
---  promptForTags = false,
---  tags = ""
---}
---```
---@field removeTags? _.lspconfig.settings.gopls.Go.RemoveTags
---Specifies whether to show the Welcome experience on first install
---
---```lua
---default = true
---```
---@field showWelcome? boolean
---@field survey? _.lspconfig.settings.gopls.Go.Survey
---@field tasks? _.lspconfig.settings.gopls.Go.Tasks
---@field terminal? _.lspconfig.settings.gopls.Go.Terminal
---Absolute path to a file containing environment variables definitions. File contents should be of the form key=value.
---@field testEnvFile? string
---Environment variables that will be passed to the process that runs the Go tests
---
---```lua
---default = {}
---```
---@field testEnvVars? table
---@field testExplorer? _.lspconfig.settings.gopls.Go.TestExplorer
---Flags to pass to `go test`. If null, then buildFlags will be used. This is not propagated to the language server.
---@field testFlags? string[]
---Run 'go test' on save for current package. It is not advised to set this to `true` when you have Auto Save enabled.
---@field testOnSave? boolean
---The Go build tags to use for when running tests. If null, then buildTags will be used.
---@field testTags? string
---Specifies the timeout for go test in ParseDuration format.
---
---```lua
---default = "30s"
---```
---@field testTimeout? string
---Environment variables that will be passed to the tools that run the Go tools (e.g. CGO_CFLAGS) and debuggee process launched by Delve. Format as string key:value pairs. When debugging, merged with `envFile` and `env` values with precedence `env` > `envFile` > `go.toolsEnvVars`.
---
---```lua
---default = {}
---```
---@field toolsEnvVars? table
---Location to install the Go tools that the extension depends on if you don't want them in your GOPATH.
---@field toolsGopath? string
---@field toolsManagement? _.lspconfig.settings.gopls.Go.ToolsManagement
---@field trace? _.lspconfig.settings.gopls.Go.Trace
---Enable intellisense, code navigation, refactoring, formatting & diagnostics for Go. The features are powered by the Go language server "gopls".
---
---```lua
---default = true
---```
---@field useLanguageServer? boolean
---Flags to pass to `go tool vet` (e.g. ["-all", "-shadow"]). Not applicable when using the language server's diagnostics.
---
---```lua
---default = {}
---```
---@field vetFlags? string[]
---Vets code on file save using 'go tool vet'. Not applicable when using the language server's diagnostics.
---
---```lua
---default = "package"
---```
---@field vetOnSave? "package" | "workspace" | "off"

---codelenses overrides the enabled/disabled state of each of gopls'
---sources of [Code Lenses](codelenses.md).
---
---Example Usage:
---
---```json5
---"gopls": {
---...
---  "codelenses": {
---    "generate": false,  // Don't show the `go generate` lens.
---  }
---...
---}
---```
---
---@class _.lspconfig.settings.gopls.Gopls.UiCodelenses
---`"generate"`: Run `go generate`
---
---This codelens source annotates any `//go:generate` comments
---with commands to run `go generate` in this directory, on
---all directories recursively beneath this one.
---
---See [Generating code](https://go.dev/blog/generate) for
---more details.
---
---
---```lua
---default = true
---```
---@field generate? boolean
---`"regenerate_cgo"`: Re-generate cgo declarations
---
---This codelens source annotates an `import "C"` declaration
---with a command to re-run the [cgo
---command](https://pkg.go.dev/cmd/cgo) to regenerate the
---corresponding Go declarations.
---
---Use this after editing the C code in comments attached to
---the import, or in C header files included by it.
---
---
---```lua
---default = true
---```
---@field regenerate_cgo? boolean
---`"run_govulncheck"`: Run govulncheck (legacy)
---
---This codelens source annotates the `module` directive in a go.mod file
---with a command to run Govulncheck asynchronously.
---
---[Govulncheck](https://go.dev/blog/vuln) is a static analysis tool that
---computes the set of functions reachable within your application, including
---dependencies; queries a database of known security vulnerabilities; and
---reports any potential problems it finds.
---
---
---```lua
---default = true
---```
---@field run_govulncheck? boolean
---`"test"`: Run tests and benchmarks
---
---This codelens source annotates each `Test` and `Benchmark`
---function in a `*_test.go` file with a command to run it.
---
---This source is off by default because VS Code has
---a client-side custom UI for testing, and because progress
---notifications are not a great UX for streamed test output.
---See:
---- golang/go#67400 for a discussion of this feature.
---- https://github.com/joaotavora/eglot/discussions/1402
---  for an alternative approach.
---
---@field test? boolean
---`"tidy"`: Tidy go.mod file
---
---This codelens source annotates the `module` directive in a
---go.mod file with a command to run [`go mod
---tidy`](https://go.dev/ref/mod#go-mod-tidy), which ensures
---that the go.mod file matches the source code in the module.
---
---
---```lua
---default = true
---```
---@field tidy? boolean
---`"upgrade_dependency"`: Update dependencies
---
---This codelens source annotates the `module` directive in a
---go.mod file with commands to:
---
---- check for available upgrades,
---- upgrade direct dependencies, and
---- upgrade all dependencies transitively.
---
---
---```lua
---default = true
---```
---@field upgrade_dependency? boolean
---`"vendor"`: Update vendor directory
---
---This codelens source annotates the `module` directive in a
---go.mod file with a command to run [`go mod
---vendor`](https://go.dev/ref/mod#go-mod-vendor), which
---creates or updates the directory named `vendor` in the
---module root so that it contains an up-to-date copy of all
---necessary package dependencies.
---
---
---```lua
---default = true
---```
---@field vendor? boolean
---(Experimental) `"vulncheck"`: Run govulncheck
---
---This codelens source annotates the `module` directive in a go.mod file
---with a command to run govulncheck synchronously.
---
---[Govulncheck](https://go.dev/blog/vuln) is a static analysis tool that
---computes the set of functions reachable within your application, including
---dependencies; queries a database of known security vulnerabilities; and
---reports any potential problems it finds.
---
---@field vulncheck? boolean

---analyses specify analyses that the user would like to enable or disable.
---A map of the names of analysis passes that should be enabled/disabled.
---A full list of analyzers that gopls uses can be found in
---[analyzers.md](https://github.com/golang/tools/blob/master/gopls/doc/analyzers.md).
---
---Example Usage:
---
---```json5
---...
---"analyses": {
---  "unreachable": false, // Disable the unreachable analyzer.
---  "unusedvariable": true  // Enable the unusedvariable analyzer.
---}
---...
---```
---
---@class _.lspconfig.settings.gopls.Gopls.UiDiagnosticAnalyses
---Apply De Morgan's law
---
---Available since
---    2021.1
---
---@field QF1001? boolean
---Convert untagged switch to tagged switch
---
---An untagged switch that compares a single variable against a series of
---values can be replaced with a tagged switch.
---
---Before:
---
---    switch {
---    case x == 1 || x == 2, x == 3:
---        ...
---    case x == 4:
---        ...
---    default:
---        ...
---    }
---
---After:
---
---    switch x {
---    case 1, 2, 3:
---        ...
---    case 4:
---        ...
---    default:
---        ...
---    }
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field QF1002? boolean
---Convert if/else-if chain to tagged switch
---
---A series of if/else-if checks comparing the same variable against
---values can be replaced with a tagged switch.
---
---Before:
---
---    if x == 1 || x == 2 {
---        ...
---    } else if x == 3 {
---        ...
---    } else {
---        ...
---    }
---
---After:
---
---    switch x {
---    case 1, 2:
---        ...
---    case 3:
---        ...
---    default:
---        ...
---    }
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field QF1003? boolean
---Use strings.ReplaceAll instead of strings.Replace with n == -1
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field QF1004? boolean
---Expand call to math.Pow
---
---Some uses of math.Pow can be simplified to basic multiplication.
---
---Before:
---
---    math.Pow(x, 2)
---
---After:
---
---    x * x
---
---Available since
---    2021.1
---
---@field QF1005? boolean
---Lift if+break into loop condition
---
---Before:
---
---    for {
---        if done {
---            break
---        }
---        ...
---    }
---
---After:
---
---    for !done {
---        ...
---    }
---
---Available since
---    2021.1
---
---@field QF1006? boolean
---Merge conditional assignment into variable declaration
---
---Before:
---
---    x := false
---    if someCondition {
---        x = true
---    }
---
---After:
---
---    x := someCondition
---
---Available since
---    2021.1
---
---@field QF1007? boolean
---Omit embedded fields from selector expression
---
---Available since
---    2021.1
---
---@field QF1008? boolean
---Use time.Time.Equal instead of == operator
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field QF1009? boolean
---Convert slice of bytes to string when printing it
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field QF1010? boolean
---Omit redundant type from variable declaration
---
---Available since
---    2021.1
---
---@field QF1011? boolean
---Use fmt.Fprintf(x, ...) instead of x.Write(fmt.Sprintf(...))
---
---Available since
---    2022.1
---
---
---```lua
---default = true
---```
---@field QF1012? boolean
---Use plain channel send or receive instead of single-case select
---
---Select statements with a single case can be replaced with a simple
---send or receive.
---
---Before:
---
---    select {
---    case x := <-ch:
---        fmt.Println(x)
---    }
---
---After:
---
---    x := <-ch
---    fmt.Println(x)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1000? boolean
---Replace for loop with call to copy
---
---Use copy() for copying elements from one slice to another. For
---arrays of identical size, you can use simple assignment.
---
---Before:
---
---    for i, x := range src {
---        dst[i] = x
---    }
---
---After:
---
---    copy(dst, src)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1001? boolean
---Omit comparison with boolean constant
---
---Before:
---
---    if x == true {}
---
---After:
---
---    if x {}
---
---Available since
---    2017.1
---
---@field S1002? boolean
---Replace call to strings.Index with strings.Contains
---
---Before:
---
---    if strings.Index(x, y) != -1 {}
---
---After:
---
---    if strings.Contains(x, y) {}
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1003? boolean
---Replace call to bytes.Compare with bytes.Equal
---
---Before:
---
---    if bytes.Compare(x, y) == 0 {}
---
---After:
---
---    if bytes.Equal(x, y) {}
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1004? boolean
---Drop unnecessary use of the blank identifier
---
---In many cases, assigning to the blank identifier is unnecessary.
---
---Before:
---
---    for _ = range s {}
---    _ = <-ch
---
---After:
---
---    for range s{}
---    <-ch
---
---Available since
---    2017.1
---
---@field S1005? boolean
---Use 'for { ... }' for infinite loops
---
---For infinite loops, using for { ... } is the most idiomatic choice.
---
---Available since
---    2017.1
---
---@field S1006? boolean
---Simplify regular expression by using raw string literal
---
---Raw string literals use backticks instead of quotation marks and do not support
---any escape sequences. This means that the backslash can be used
---freely, without the need of escaping.
---
---Since regular expressions have their own escape sequences, raw strings
---can improve their readability.
---
---Before:
---
---    regexp.Compile("\\A(\\w+) profile: total \\d+\\n\\z")
---
---After:
---
---    regexp.Compile(`\A(\w+) profile: total \d+\n\z`)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1007? boolean
---Simplify returning boolean expression
---
---Before:
---
---    if <expr> {
---        return true
---    }
---    return false
---
---After:
---
---    return <expr>
---
---Available since
---    2017.1
---
---@field S1008? boolean
---Omit redundant nil check on slices, maps, and channels
---
---The len function is defined for all slices, maps, and
---channels, even nil ones, which have a length of zero. It is not necessary to
---check for nil before checking that their length is not zero.
---
---Before:
---
---    if x != nil && len(x) != 0 {}
---
---After:
---
---    if len(x) != 0 {}
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1009? boolean
---Omit default slice index
---
---When slicing, the second index defaults to the length of the value,
---making s[n:len(s)] and s[n:] equivalent.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1010? boolean
---Use a single append to concatenate two slices
---
---Before:
---
---    for _, e := range y {
---        x = append(x, e)
---    }
---    
---    for i := range y {
---        x = append(x, y[i])
---    }
---    
---    for i := range y {
---        v := y[i]
---        x = append(x, v)
---    }
---
---After:
---
---    x = append(x, y...)
---    x = append(x, y...)
---    x = append(x, y...)
---
---Available since
---    2017.1
---
---@field S1011? boolean
---Replace time.Now().Sub(x) with time.Since(x)
---
---The time.Since helper has the same effect as using time.Now().Sub(x)
---but is easier to read.
---
---Before:
---
---    time.Now().Sub(x)
---
---After:
---
---    time.Since(x)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1012? boolean
---Use a type conversion instead of manually copying struct fields
---
---Two struct types with identical fields can be converted between each
---other. In older versions of Go, the fields had to have identical
---struct tags. Since Go 1.8, however, struct tags are ignored during
---conversions. It is thus not necessary to manually copy every field
---individually.
---
---Before:
---
---    var x T1
---    y := T2{
---        Field1: x.Field1,
---        Field2: x.Field2,
---    }
---
---After:
---
---    var x T1
---    y := T2(x)
---
---Available since
---    2017.1
---
---@field S1016? boolean
---Replace manual trimming with strings.TrimPrefix
---
---Instead of using strings.HasPrefix and manual slicing, use the
---strings.TrimPrefix function. If the string doesn't start with the
---prefix, the original string will be returned. Using strings.TrimPrefix
---reduces complexity, and avoids common bugs, such as off-by-one
---mistakes.
---
---Before:
---
---    if strings.HasPrefix(str, prefix) {
---        str = str[len(prefix):]
---    }
---
---After:
---
---    str = strings.TrimPrefix(str, prefix)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1017? boolean
---Use 'copy' for sliding elements
---
---copy() permits using the same source and destination slice, even with
---overlapping ranges. This makes it ideal for sliding elements in a
---slice.
---
---Before:
---
---    for i := 0; i < n; i++ {
---        bs[i] = bs[offset+i]
---    }
---
---After:
---
---    copy(bs[:n], bs[offset:])
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1018? boolean
---Simplify 'make' call by omitting redundant arguments
---
---The 'make' function has default values for the length and capacity
---arguments. For channels, the length defaults to zero, and for slices,
---the capacity defaults to the length.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1019? boolean
---Omit redundant nil check in type assertion
---
---Before:
---
---    if _, ok := i.(T); ok && i != nil {}
---
---After:
---
---    if _, ok := i.(T); ok {}
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1020? boolean
---Merge variable declaration and assignment
---
---Before:
---
---    var x uint
---    x = 1
---
---After:
---
---    var x uint = 1
---
---Available since
---    2017.1
---
---@field S1021? boolean
---Omit redundant control flow
---
---Functions that have no return value do not need a return statement as
---the final statement of the function.
---
---Switches in Go do not have automatic fallthrough, unlike languages
---like C. It is not necessary to have a break statement as the final
---statement in a case block.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1023? boolean
---Replace x.Sub(time.Now()) with time.Until(x)
---
---The time.Until helper has the same effect as using x.Sub(time.Now())
---but is easier to read.
---
---Before:
---
---    x.Sub(time.Now())
---
---After:
---
---    time.Until(x)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1024? boolean
---Don't use fmt.Sprintf("%s", x) unnecessarily
---
---In many instances, there are easier and more efficient ways of getting
---a value's string representation. Whenever a value's underlying type is
---a string already, or the type has a String method, they should be used
---directly.
---
---Given the following shared definitions
---
---    type T1 string
---    type T2 int
---
---    func (T2) String() string { return "Hello, world" }
---
---    var x string
---    var y T1
---    var z T2
---
---we can simplify
---
---    fmt.Sprintf("%s", x)
---    fmt.Sprintf("%s", y)
---    fmt.Sprintf("%s", z)
---
---to
---
---    x
---    string(y)
---    z.String()
---
---Available since
---    2017.1
---
---@field S1025? boolean
---Simplify error construction with fmt.Errorf
---
---Before:
---
---    errors.New(fmt.Sprintf(...))
---
---After:
---
---    fmt.Errorf(...)
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1028? boolean
---Range over the string directly
---
---Ranging over a string will yield byte offsets and runes. If the offset
---isn't used, this is functionally equivalent to converting the string
---to a slice of runes and ranging over that. Ranging directly over the
---string will be more performant, however, as it avoids allocating a new
---slice, the size of which depends on the length of the string.
---
---Before:
---
---    for _, r := range []rune(s) {}
---
---After:
---
---    for _, r := range s {}
---
---Available since
---    2017.1
---
---@field S1029? boolean
---Use bytes.Buffer.String or bytes.Buffer.Bytes
---
---bytes.Buffer has both a String and a Bytes method. It is almost never
---necessary to use string(buf.Bytes()) or []byte(buf.String()) – simply
---use the other method.
---
---The only exception to this are map lookups. Due to a compiler optimization,
---m[string(buf.Bytes())] is more efficient than m[buf.String()].
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1030? boolean
---Omit redundant nil check around loop
---
---You can use range on nil slices and maps, the loop will simply never
---execute. This makes an additional nil check around the loop
---unnecessary.
---
---Before:
---
---    if s != nil {
---        for _, x := range s {
---            ...
---        }
---    }
---
---After:
---
---    for _, x := range s {
---        ...
---    }
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field S1031? boolean
---Use sort.Ints(x), sort.Float64s(x), and sort.Strings(x)
---
---The sort.Ints, sort.Float64s and sort.Strings functions are easier to
---read than sort.Sort(sort.IntSlice(x)), sort.Sort(sort.Float64Slice(x))
---and sort.Sort(sort.StringSlice(x)).
---
---Before:
---
---    sort.Sort(sort.StringSlice(x))
---
---After:
---
---    sort.Strings(x)
---
---Available since
---    2019.1
---
---
---```lua
---default = true
---```
---@field S1032? boolean
---Unnecessary guard around call to 'delete'
---
---Calling delete on a nil map is a no-op.
---
---Available since
---    2019.2
---
---
---```lua
---default = true
---```
---@field S1033? boolean
---Use result of type assertion to simplify cases
---
---Available since
---    2019.2
---
---
---```lua
---default = true
---```
---@field S1034? boolean
---Redundant call to net/http.CanonicalHeaderKey in method call on net/http.Header
---
---The methods on net/http.Header, namely Add, Del, Get
---and Set, already canonicalize the given header name.
---
---Available since
---    2020.1
---
---
---```lua
---default = true
---```
---@field S1035? boolean
---Unnecessary guard around map access
---
---When accessing a map key that doesn't exist yet, one receives a zero
---value. Often, the zero value is a suitable value, for example when
---using append or doing integer math.
---
---The following
---
---    if _, ok := m["foo"]; ok {
---        m["foo"] = append(m["foo"], "bar")
---    } else {
---        m["foo"] = []string{"bar"}
---    }
---
---can be simplified to
---
---    m["foo"] = append(m["foo"], "bar")
---
---and
---
---    if _, ok := m2["k"]; ok {
---        m2["k"] += 4
---    } else {
---        m2["k"] = 4
---    }
---
---can be simplified to
---
---    m["k"] += 4
---
---Available since
---    2020.1
---
---
---```lua
---default = true
---```
---@field S1036? boolean
---Elaborate way of sleeping
---
---Using a select statement with a single case receiving
---from the result of time.After is a very elaborate way of sleeping that
---can much simpler be expressed with a simple call to time.Sleep.
---
---Available since
---    2020.1
---
---
---```lua
---default = true
---```
---@field S1037? boolean
---Unnecessarily complex way of printing formatted string
---
---Instead of using fmt.Print(fmt.Sprintf(...)), one can use fmt.Printf(...).
---
---Available since
---    2020.1
---
---
---```lua
---default = true
---```
---@field S1038? boolean
---Unnecessary use of fmt.Sprint
---
---Calling fmt.Sprint with a single string argument is unnecessary
---and identical to using the string directly.
---
---Available since
---    2020.1
---
---
---```lua
---default = true
---```
---@field S1039? boolean
---Type assertion to current type
---
---The type assertion x.(SomeInterface), when x already has type
---SomeInterface, can only fail if x is nil. Usually, this is
---left-over code from when x had a different type and you can safely
---delete the type assertion. If you want to check that x is not nil,
---consider being explicit and using an actual if x == nil comparison
---instead of relying on the type assertion panicking.
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field S1040? boolean
---Invalid regular expression
---
---Available since
---    2017.1
---
---@field SA1000? boolean
---Invalid template
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1001? boolean
---Invalid format in time.Parse
---
---time.Parse requires a layout string that uses Go's reference time:
---'Mon Jan 2 15:04:05 MST 2006'. The layout must represent this date and time
---exactly. See https://pkg.go.dev/time#pkg-constants for layout examples.
---
---Available since
---    2017.1
---
---@field SA1002? boolean
---Unsupported argument to functions in encoding/binary
---
---The encoding/binary package can only serialize types with known sizes.
---This precludes the use of the int and uint types, as their sizes
---differ on different architectures. Furthermore, it doesn't support
---serializing maps, channels, strings, or functions.
---
---Before Go 1.8, bool wasn't supported, either.
---
---Available since
---    2017.1
---
---@field SA1003? boolean
---Suspiciously small untyped constant in time.Sleep
---
---The time.Sleep function takes a time.Duration as its only argument.
---Durations are expressed in nanoseconds. Thus, calling time.Sleep(1)
---will sleep for 1 nanosecond. This is a common source of bugs, as sleep
---functions in other languages often accept seconds or milliseconds.
---
---The time package provides constants such as time.Second to express
---large durations. These can be combined with arithmetic to express
---arbitrary durations, for example 5 * time.Second for 5 seconds.
---
---If you truly meant to sleep for a tiny amount of time, use
---n * time.Nanosecond to signal to Staticcheck that you did mean to sleep
---for some amount of nanoseconds.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1004? boolean
---Invalid first argument to exec.Command
---
---os/exec runs programs directly (using variants of the fork and exec
---system calls on Unix systems). This shouldn't be confused with running
---a command in a shell. The shell will allow for features such as input
---redirection, pipes, and general scripting. The shell is also
---responsible for splitting the user's input into a program name and its
---arguments. For example, the equivalent to
---
---    ls / /tmp
---
---would be
---
---    exec.Command("ls", "/", "/tmp")
---
---If you want to run a command in a shell, consider using something like
---the following – but be aware that not all systems, particularly
---Windows, will have a /bin/sh program:
---
---    exec.Command("/bin/sh", "-c", "ls | grep Awesome")
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1005? boolean
---Invalid URL in net/url.Parse
---
---Available since
---    2017.1
---
---@field SA1007? boolean
---Non-canonical key in http.Header map
---
---Keys in http.Header maps are canonical, meaning they follow a specific
---combination of uppercase and lowercase letters. Methods such as
---http.Header.Add and http.Header.Del convert inputs into this canonical
---form before manipulating the map.
---
---When manipulating http.Header maps directly, as opposed to using the
---provided methods, care should be taken to stick to canonical form in
---order to avoid inconsistencies. The following piece of code
---demonstrates one such inconsistency:
---
---    h := http.Header{}
---    h["etag"] = []string{"1234"}
---    h.Add("etag", "5678")
---    fmt.Println(h)
---
---    // Output:
---    // map[Etag:[5678] etag:[1234]]
---
---The easiest way of obtaining the canonical form of a key is to use
---http.CanonicalHeaderKey.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1008? boolean
---(*regexp.Regexp).FindAll called with n == 0, which will always return zero results
---
---If n >= 0, the function returns at most n matches/submatches. To
---return all results, specify a negative number.
---
---Available since
---    2017.1
---
---@field SA1010? boolean
---Various methods in the 'strings' package expect valid UTF-8, but invalid input is provided
---
---Available since
---    2017.1
---
---@field SA1011? boolean
---A nil context.Context is being passed to a function, consider using context.TODO instead
---
---The context package prohibits the use of a nil context.
---If no parent context is available, a new context should be used,
---e.g. context.TODO or context.Background.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1012? boolean
---io.Seeker.Seek is being called with the whence constant as the first argument, but it should be the second
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1013? boolean
---Non-pointer value passed to Unmarshal or Decode
---
---Functions such as encoding/json.Unmarshal and
---(*encoding/json.Decoder).Decode require a pointer to the value that should
---be populated. Passing a non-pointer value results in the function returning an
---error at runtime, as it cannot modify the target value.
---
---Available since
---    2017.1
---
---@field SA1014? boolean
---Using time.Tick in a way that will leak. Consider using time.NewTicker, and only use time.Tick in tests, commands and endless functions
---
---Before Go 1.23, time.Tickers had to be closed to be able to be garbage
---collected. Since time.Tick doesn't make it possible to close the underlying
---ticker, using it repeatedly would leak memory.
---
---Go 1.23 fixes this by allowing tickers to be collected even if they weren't closed.
---
---Available since
---    2017.1
---
---@field SA1015? boolean
---Trapping a signal that cannot be trapped
---
---Not all signals can be intercepted by a process. Specifically, on
---UNIX-like systems, the syscall.SIGKILL and syscall.SIGSTOP signals are
---never passed to the process, but instead handled directly by the
---kernel. It is therefore pointless to try and handle these signals.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA1016? boolean
---Channels used with os/signal.Notify should be buffered
---
---The os/signal package uses non-blocking channel sends when delivering
---signals. If the receiving end of the channel isn't ready and the
---channel is either unbuffered or full, the signal will be dropped. To
---avoid missing signals, the channel should be buffered and of the
---appropriate size. For a channel used for notification of just one
---signal value, a buffer of size 1 is sufficient.
---
---Available since
---    2017.1
---
---@field SA1017? boolean
---strings.Replace called with n == 0, which does nothing
---
---With n == 0, zero instances will be replaced. To replace all
---instances, use a negative number, or use strings.ReplaceAll.
---
---Available since
---    2017.1
---
---@field SA1018? boolean
---Using an invalid host:port pair with a net.Listen-related function
---
---Functions such as net.Listen, net.ListenTCP, and similar,
---expect a valid network address in the form of host:port. The host, the port,
---or both, can be omitted, e.g. localhost:8080, :8080 or : are valid
---host:port pairs.
---See https://pkg.go.dev/net#Listen for the full documentation.
---
---Available since
---    2017.1
---
---@field SA1020? boolean
---Using bytes.Equal to compare two net.IP
---
---A net.IP stores an IPv4 or IPv6 address as a slice of bytes. The
---length of the slice for an IPv4 address, however, can be either 4 or
---16 bytes long, using different ways of representing IPv4 addresses. In
---order to correctly compare two net.IPs, the net.IP.Equal method should
---be used, as it takes both representations into account.
---
---Available since
---    2017.1
---
---@field SA1021? boolean
---Modifying the buffer in an io.Writer implementation
---
---Write must not modify the slice data, even temporarily.
---
---Available since
---    2017.1
---
---@field SA1023? boolean
---A string cutset contains duplicate characters
---
---The strings.TrimLeft and strings.TrimRight functions take cutsets, not
---prefixes. A cutset is treated as a set of characters to remove from a
---string. For example,
---
---    strings.TrimLeft("42133word", "1234")
---
---will result in the string "word" – any characters that are 1, 2, 3 or
---4 are cut from the left of the string.
---
---In order to remove one string from another, use strings.TrimPrefix instead.
---
---Available since
---    2017.1
---
---@field SA1024? boolean
---It is not possible to use (*time.Timer).Reset's return value correctly
---
---Available since
---    2019.1
---
---@field SA1025? boolean
---Cannot marshal channels or functions
---
---Available since
---    2019.2
---
---@field SA1026? boolean
---Atomic access to 64-bit variable must be 64-bit aligned
---
---On ARM, x86-32, and 32-bit MIPS, it is the caller's responsibility to
---arrange for 64-bit alignment of 64-bit words accessed atomically. The
---first word in a variable or in an allocated struct, array, or slice
---can be relied upon to be 64-bit aligned.
---
---You can use the structlayout tool to inspect the alignment of fields
---in a struct.
---
---Available since
---    2019.2
---
---@field SA1027? boolean
---sort.Slice can only be used on slices
---
---The first argument of sort.Slice must be a slice.
---
---Available since
---    2020.1
---
---@field SA1028? boolean
---Inappropriate key in call to context.WithValue
---
---The provided key must be comparable and should not be
---of type string or any other built-in type to avoid collisions between
---packages using context. Users of WithValue should define their own
---types for keys.
---
---To avoid allocating when assigning to an interface{},
---context keys often have concrete type struct{}. Alternatively,
---exported context key variables' static type should be a pointer or
---interface.
---
---Available since
---    2020.1
---
---@field SA1029? boolean
---Invalid argument in call to a strconv function
---
---This check validates the format, number base and bit size arguments of
---the various parsing and formatting functions in strconv.
---
---Available since
---    2021.1
---
---@field SA1030? boolean
---Overlapping byte slices passed to an encoder
---
---In an encoding function of the form Encode(dst, src), dst and
---src were found to reference the same memory. This can result in
---src bytes being overwritten before they are read, when the encoder
---writes more than one byte per src byte.
---
---Available since
---    2024.1
---
---@field SA1031? boolean
---Wrong order of arguments to errors.Is
---
---The first argument of the function errors.Is is the error
---that we have and the second argument is the error we're trying to match against.
---For example:
---
---	if errors.Is(err, io.EOF) { ... }
---
---This check detects some cases where the two arguments have been swapped. It
---flags any calls where the first argument is referring to a package-level error
---variable, such as
---
---	if errors.Is(io.EOF, err) { /* this is wrong */ }
---
---Available since
---    2024.1
---
---@field SA1032? boolean
---Empty critical section, did you mean to defer the unlock?
---
---Empty critical sections of the kind
---
---    mu.Lock()
---    mu.Unlock()
---
---are very often a typo, and the following was intended instead:
---
---    mu.Lock()
---    defer mu.Unlock()
---
---Do note that sometimes empty critical sections can be useful, as a
---form of signaling to wait on another goroutine. Many times, there are
---simpler ways of achieving the same effect. When that isn't the case,
---the code should be amply commented to avoid confusion. Combining such
---comments with a //lint:ignore directive can be used to suppress this
---rare false positive.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA2001? boolean
---Called testing.T.FailNow or SkipNow in a goroutine, which isn't allowed
---
---Available since
---    2017.1
---
---@field SA2002? boolean
---Deferred Lock right after locking, likely meant to defer Unlock instead
---
---Deferring a call to Lock immediately after locking is almost always
---a typo. For example:
---
---    mu.Lock()
---    defer mu.Lock()
---
---While this does not strictly guarantee a deadlock depending on how the
---surrounding code is structured, it is highly likely to be a mistake.
---The intended code was likely this:
---
---    mu.Lock()
---    defer mu.Unlock()
---
---Available since
---    2017.1
---
---@field SA2003? boolean
---TestMain doesn't call os.Exit, hiding test failures
---
---Test executables (and in turn 'go test') exit with a non-zero status
---code if any tests failed. When specifying your own TestMain function,
---it is your responsibility to arrange for this, by calling os.Exit with
---the correct code. The correct code is returned by (*testing.M).Run, so
---the usual way of implementing TestMain is to end it with
---os.Exit(m.Run()).
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA3000? boolean
---Assigning to b.N in benchmarks distorts the results
---
---The testing package dynamically sets b.N to improve the reliability of
---benchmarks and uses it in computations to determine the duration of a
---single operation. Benchmark code must not alter b.N as this would
---falsify results.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA3001? boolean
---Binary operator has identical expressions on both sides
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4000? boolean
---&*x gets simplified to x, it does not copy x
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4001? boolean
---Comparing unsigned values against negative values is pointless
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4003? boolean
---The loop exits unconditionally after one iteration
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4004? boolean
---Field assignment that will never be observed. Did you mean to use a pointer receiver?
---
---Available since
---    2021.1
---
---@field SA4005? boolean
---A value assigned to a variable is never read before being overwritten. Forgotten error check or dead code?
---
---Available since
---    2017.1
---
---@field SA4006? boolean
---The variable in the loop condition never changes, are you incrementing the wrong variable?
---
---For example:
---
---	for i := 0; i < 10; j++ { ... }
---
---This may also occur when a loop can only execute once because of unconditional
---control flow that terminates the loop. For example, when a loop body contains an
---unconditional break, return, or panic:
---
---	func f() {
---		panic("oops")
---	}
---	func g() {
---		for i := 0; i < 10; i++ {
---			// f unconditionally calls panic, which means "i" is
---			// never incremented.
---			f()
---		}
---	}
---
---Available since
---    2017.1
---
---@field SA4008? boolean
---A function argument is overwritten before its first use
---
---Available since
---    2017.1
---
---@field SA4009? boolean
---The result of append will never be observed anywhere
---
---Calls to append produce a new slice value. When the result of
---append is assigned to a variable that is never subsequently read, the
---append operation may have an unintended effect.
---
---Available since
---    2017.1
---
---@field SA4010? boolean
---Break statement with no effect. Did you mean to break out of an outer loop?
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4011? boolean
---Comparing a value against NaN even though no value is equal to NaN
---
---Available since
---    2017.1
---
---@field SA4012? boolean
---Negating a boolean twice (!!b) is the same as writing b. This is either redundant, or a typo.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4013? boolean
---An if/else if chain has repeated conditions and no side-effects; if the condition didn't match the first time, it won't match the second time, either
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4014? boolean
---Calling functions like math.Ceil on floats converted from integers doesn't do anything useful
---
---Available since
---    2017.1
---
---@field SA4015? boolean
---Certain bitwise operations, such as x ^ 0, do not do anything useful
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4016? boolean
---Discarding the return values of a function without side effects, making the call pointless
---
---Available since
---    2017.1
---
---@field SA4017? boolean
---Self-assignment of variables
---
---Available since
---    2017.1
---
---@field SA4018? boolean
---Multiple, identical build constraints in the same file
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA4019? boolean
---Unreachable case clause in a type switch
---
---In a type switch like the following
---
---    type T struct{}
---    func (T) Read(b []byte) (int, error) { return 0, nil }
---
---    var v any = T{}
---
---    switch v.(type) {
---    case io.Reader:
---        // ...
---    case T:
---        // unreachable
---    }
---
---the second case clause can never be reached because T implements
---io.Reader and case clauses are evaluated in source order.
---
---Another example:
---
---    type T struct{}
---    func (T) Read(b []byte) (int, error) { return 0, nil }
---    func (T) Close() error { return nil }
---
---    var v any = T{}
---
---    switch v.(type) {
---    case io.Reader:
---        // ...
---    case io.ReadCloser:
---        // unreachable
---    }
---
---Even though T has a Close method and thus implements io.ReadCloser,
---io.Reader will always match first. The method set of io.Reader is a
---subset of io.ReadCloser. Thus it is impossible to match the second
---case without matching the first case.
---
---
---Structurally equivalent interfaces
---
---A special case of the previous example are structurally identical
---interfaces. Given these declarations
---
---    type T error
---    type V error
---
---    func doSomething() error {
---        err, ok := doAnotherThing()
---        if ok {
---            return T(err)
---        }
---
---        return U(err)
---    }
---
---the following type switch will have an unreachable case clause:
---
---    switch doSomething().(type) {
---    case T:
---        // ...
---    case V:
---        // unreachable
---    }
---
---T will always match before V because they are structurally equivalent
---and therefore doSomething()'s return value implements both.
---
---Available since
---    2019.2
---
---
---```lua
---default = true
---```
---@field SA4020? boolean
---Comparing the address of a variable against nil
---
---Code such as 'if &x == nil' is meaningless, because taking the address of a variable always yields a non-nil pointer.
---
---Available since
---    2020.1
---
---
---```lua
---default = true
---```
---@field SA4022? boolean
---Impossible comparison of interface value with untyped nil
---
---Under the covers, interfaces are implemented as two elements, a
---type T and a value V. V is a concrete value such as an int,
---struct or pointer, never an interface itself, and has type T. For
---instance, if we store the int value 3 in an interface, the
---resulting interface value has, schematically, (T=int, V=3). The
---value V is also known as the interface's dynamic value, since a
---given interface variable might hold different values V (and
---corresponding types T) during the execution of the program.
---
---An interface value is nil only if the V and T are both
---unset, (T=nil, V is not set), In particular, a nil interface will
---always hold a nil type. If we store a nil pointer of type *int
---inside an interface value, the inner type will be *int regardless
---of the value of the pointer: (T=*int, V=nil). Such an interface
---value will therefore be non-nil even when the pointer value V
---inside is nil.
---
---This situation can be confusing, and arises when a nil value is
---stored inside an interface value such as an error return:
---
---    func returnsError() error {
---        var p *MyError = nil
---        if bad() {
---            p = ErrBad
---        }
---        return p // Will always return a non-nil error.
---    }
---
---If all goes well, the function returns a nil p, so the return
---value is an error interface value holding (T=*MyError, V=nil).
---This means that if the caller compares the returned error to nil,
---it will always look as if there was an error even if nothing bad
---happened. To return a proper nil error to the caller, the
---function must return an explicit nil:
---
---    func returnsError() error {
---        if bad() {
---            return ErrBad
---        }
---        return nil
---    }
---
---It's a good idea for functions that return errors always to use
---the error type in their signature (as we did above) rather than a
---concrete type such as *MyError, to help guarantee the error is
---created correctly. As an example, os.Open returns an error even
---though, if not nil, it's always of concrete type *os.PathError.
---
---Similar situations to those described here can arise whenever
---interfaces are used. Just keep in mind that if any concrete value
---has been stored in the interface, the interface will not be nil.
---For more information, see The Laws of
---Reflection at https://golang.org/doc/articles/laws_of_reflection.html.
---
---This text has been copied from
---https://golang.org/doc/faq#nil_error, licensed under the Creative
---Commons Attribution 3.0 License.
---
---Available since
---    2020.2
---
---@field SA4023? boolean
---Checking for impossible return value from a builtin function
---
---Return values of the len and cap builtins cannot be negative.
---
---See https://golang.org/pkg/builtin/#len and https://golang.org/pkg/builtin/#cap.
---
---Example:
---
---    if len(slice) < 0 {
---        fmt.Println("unreachable code")
---    }
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field SA4024? boolean
---Integer division of literals that results in zero
---
---When dividing two integer constants, the result will
---also be an integer. Thus, a division such as 2 / 3 results in 0.
---This is true for all of the following examples:
---
---	_ = 2 / 3
---	const _ = 2 / 3
---	const _ float64 = 2 / 3
---	_ = float64(2 / 3)
---
---Staticcheck will flag such divisions if both sides of the division are
---integer literals, as it is highly unlikely that the division was
---intended to truncate to zero. Staticcheck will not flag integer
---division involving named constants, to avoid noisy positives.
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field SA4025? boolean
---Go constants cannot express negative zero
---
---In IEEE 754 floating point math, zero has a sign and can be positive
---or negative. This can be useful in certain numerical code.
---
---Go constants, however, cannot express negative zero. This means that
---the literals -0.0 and 0.0 have the same ideal value (zero) and
---will both represent positive zero at runtime.
---
---To explicitly and reliably create a negative zero, you can use the
---math.Copysign function: math.Copysign(0, -1).
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field SA4026? boolean
---(*net/url.URL).Query returns a copy, modifying it doesn't change the URL
---
---(*net/url.URL).Query parses the current value of net/url.URL.RawQuery
---and returns it as a map of type net/url.Values. Subsequent changes to
---this map will not affect the URL unless the map gets encoded and
---assigned to the URL's RawQuery.
---
---As a consequence, the following code pattern is an expensive no-op:
---u.Query().Add(key, value).
---
---Available since
---    2021.1
---
---
---```lua
---default = true
---```
---@field SA4027? boolean
---x % 1 is always zero
---
---Available since
---    2022.1
---
---
---```lua
---default = true
---```
---@field SA4028? boolean
---Ineffective attempt at sorting slice
---
---sort.Float64Slice, sort.IntSlice, and sort.StringSlice are
---types, not functions. Doing x = sort.StringSlice(x) does nothing,
---especially not sort any values. The correct usage is
---sort.Sort(sort.StringSlice(x)) or sort.StringSlice(x).Sort(),
---but there are more convenient helpers, namely sort.Float64s,
---sort.Ints, and sort.Strings.
---
---Available since
---    2022.1
---
---
---```lua
---default = true
---```
---@field SA4029? boolean
---Ineffective attempt at generating random number
---
---Functions in the math/rand package that accept upper limits, such
---as Intn, generate random numbers in the half-open interval [0,n). In
---other words, the generated numbers will be >= 0 and < n – they
---don't include n. rand.Intn(1) therefore doesn't generate 0
---or 1, it always generates 0.
---
---Available since
---    2022.1
---
---
---```lua
---default = true
---```
---@field SA4030? boolean
---Checking never-nil value against nil
---
---Available since
---    2022.1
---
---@field SA4031? boolean
---Comparing runtime.GOOS or runtime.GOARCH against impossible value
---
---Available since
---    2024.1
---
---
---```lua
---default = true
---```
---@field SA4032? boolean
---Assignment to nil map
---
---Available since
---    2017.1
---
---@field SA5000? boolean
---Deferring Close before checking for a possible error
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA5001? boolean
---The empty for loop ('for {}') spins and can block the scheduler
---
---Available since
---    2017.1
---
---@field SA5002? boolean
---Defers in infinite loops will never execute
---
---Defers are scoped to the surrounding function, not the surrounding
---block. In a function that never returns, i.e. one containing an
---infinite loop, defers will never execute.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA5003? boolean
---'for { select { ...' with an empty default branch spins
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA5004? boolean
---The finalizer references the finalized object, preventing garbage collection
---
---A finalizer is a function associated with an object that runs when the
---garbage collector is ready to collect said object, that is when the
---object is no longer referenced by anything.
---
---If the finalizer references the object, however, it will always remain
---as the final reference to that object, preventing the garbage
---collector from collecting the object. The finalizer will never run,
---and the object will never be collected, leading to a memory leak. That
---is why the finalizer should instead use its first argument to operate
---on the object. That way, the number of references can temporarily go
---to zero before the object is being passed to the finalizer.
---
---Available since
---    2017.1
---
---@field SA5005? boolean
---Infinite recursive call
---
---A function that calls itself recursively needs to have an exit
---condition. Otherwise it will recurse forever, until the system runs
---out of memory.
---
---This issue can be caused by simple bugs such as forgetting to add an
---exit condition. It can also happen "on purpose". Some languages have
---tail call optimization which makes certain infinite recursive calls
---safe to use. Go, however, does not implement TCO, and as such a loop
---should be used instead.
---
---Available since
---    2017.1
---
---@field SA5007? boolean
---Invalid struct tag
---
---Available since
---    2019.2
---
---
---```lua
---default = true
---```
---@field SA5008? boolean
---Impossible type assertion
---
---Some type assertions can be statically proven to be
---impossible. This is the case when the method sets of both
---arguments of the type assertion conflict with each other, for
---example by containing the same method with different
---signatures.
---
---The Go compiler already applies this check when asserting from an
---interface value to a concrete type. If the concrete type misses
---methods from the interface, or if function signatures don't match,
---then the type assertion can never succeed.
---
---This check applies the same logic when asserting from one interface to
---another. If both interface types contain the same method but with
---different signatures, then the type assertion can never succeed,
---either.
---
---Available since
---    2020.1
---
---@field SA5010? boolean
---Passing odd-sized slice to function expecting even size
---
---Some functions that take slices as parameters expect the slices to have an even number of elements. 
---Often, these functions treat elements in a slice as pairs. 
---For example, strings.NewReplacer takes pairs of old and new strings, 
---and calling it with an odd number of elements would be an error.
---
---Available since
---    2020.2
---
---@field SA5012? boolean
---Using regexp.Match or related in a loop, should use regexp.Compile
---
---Available since
---    2017.1
---
---@field SA6000? boolean
---Missing an optimization opportunity when indexing maps by byte slices
---
---Map keys must be comparable, which precludes the use of byte slices.
---This usually leads to using string keys and converting byte slices to
---strings.
---
---Normally, a conversion of a byte slice to a string needs to copy the data and
---causes allocations. The compiler, however, recognizes m[string(b)] and
---uses the data of b directly, without copying it, because it knows that
---the data can't change during the map lookup. This leads to the
---counter-intuitive situation that
---
---    k := string(b)
---    println(m[k])
---    println(m[k])
---
---will be less efficient than
---
---    println(m[string(b)])
---    println(m[string(b)])
---
---because the first version needs to copy and allocate, while the second
---one does not.
---
---For some history on this optimization, check out commit
---f5f5a8b6209f84961687d993b93ea0d397f5d5bf in the Go repository.
---
---Available since
---    2017.1
---
---@field SA6001? boolean
---Storing non-pointer values in sync.Pool allocates memory
---
---A sync.Pool is used to avoid unnecessary allocations and reduce the
---amount of work the garbage collector has to do.
---
---When passing a value that is not a pointer to a function that accepts
---an interface, the value needs to be placed on the heap, which means an
---additional allocation. Slices are a common thing to put in sync.Pools,
---and they're structs with 3 fields (length, capacity, and a pointer to
---an array). In order to avoid the extra allocation, one should store a
---pointer to the slice instead.
---
---See the comments on https://go-review.googlesource.com/c/go/+/24371
---that discuss this problem.
---
---Available since
---    2017.1
---
---@field SA6002? boolean
---Converting a string to a slice of runes before ranging over it
---
---You may want to loop over the runes in a string. Instead of converting
---the string to a slice of runes and looping over that, you can loop
---over the string itself. That is,
---
---    for _, r := range s {}
---
---and
---
---    for _, r := range []rune(s) {}
---
---will yield the same values. The first version, however, will be faster
---and avoid unnecessary memory allocations.
---
---Do note that if you are interested in the indices, ranging over a
---string and over a slice of runes will yield different indices. The
---first one yields byte offsets, while the second one yields indices in
---the slice of runes.
---
---Available since
---    2017.1
---
---@field SA6003? boolean
---Inefficient string comparison with strings.ToLower or strings.ToUpper
---
---Converting two strings to the same case and comparing them like so
---
---    if strings.ToLower(s1) == strings.ToLower(s2) {
---        ...
---    }
---
---is significantly more expensive than comparing them with
---strings.EqualFold(s1, s2). This is due to memory usage as well as
---computational complexity.
---
---strings.ToLower will have to allocate memory for the new strings, as
---well as convert both strings fully, even if they differ on the very
---first byte. strings.EqualFold, on the other hand, compares the strings
---one character at a time. It doesn't need to create two intermediate
---strings and can return as soon as the first non-matching character has
---been found.
---
---For a more in-depth explanation of this issue, see
---https://blog.digitalocean.com/how-to-efficiently-compare-strings-in-go/
---
---Available since
---    2019.2
---
---
---```lua
---default = true
---```
---@field SA6005? boolean
---Using io.WriteString to write []byte
---
---Using io.WriteString to write a slice of bytes, as in
---
---    io.WriteString(w, string(b))
---
---is both unnecessary and inefficient. Converting from []byte to string
---has to allocate and copy the data, and we could simply use w.Write(b)
---instead.
---
---Available since
---    2024.1
---
---
---```lua
---default = true
---```
---@field SA6006? boolean
---Defers in range loops may not run when you expect them to
---
---Available since
---    2017.1
---
---@field SA9001? boolean
---Using a non-octal os.FileMode that looks like it was meant to be in octal.
---
---Available since
---    2017.1
---
---
---```lua
---default = true
---```
---@field SA9002? boolean
---Empty body in an if or else branch
---
---Available since
---    2017.1, non-default
---
---@field SA9003? boolean
---Only the first constant has an explicit type
---
---In a constant declaration such as the following:
---
---    const (
---        First byte = 1
---        Second     = 2
---    )
---
---the constant Second does not have the same type as the constant First.
---This construct shouldn't be confused with
---
---    const (
---        First byte = iota
---        Second
---    )
---
---where First and Second do indeed have the same type. The type is only
---passed on when no explicit value is assigned to the constant.
---
---When declaring enumerations with explicit values it is therefore
---important not to write
---
---    const (
---          EnumFirst EnumType = 1
---          EnumSecond         = 2
---          EnumThird          = 3
---    )
---
---This discrepancy in types can cause various confusing behaviors and
---bugs.
---
---
---Wrong type in variable declarations
---
---The most obvious issue with such incorrect enumerations expresses
---itself as a compile error:
---
---    package pkg
---
---    const (
---        EnumFirst  uint8 = 1
---        EnumSecond       = 2
---    )
---
---    func fn(useFirst bool) {
---        x := EnumSecond
---        if useFirst {
---            x = EnumFirst
---        }
---    }
---
---fails to compile with
---
---    ./const.go:11:5: cannot use EnumFirst (type uint8) as type int in assignment
---
---
---Losing method sets
---
---A more subtle issue occurs with types that have methods and optional
---interfaces. Consider the following:
---
---    package main
---
---    import "fmt"
---
---    type Enum int
---
---    func (e Enum) String() string {
---        return "an enum"
---    }
---
---    const (
---        EnumFirst  Enum = 1
---        EnumSecond      = 2
---    )
---
---    func main() {
---        fmt.Println(EnumFirst)
---        fmt.Println(EnumSecond)
---    }
---
---This code will output
---
---    an enum
---    2
---
---as EnumSecond has no explicit type, and thus defaults to int.
---
---Available since
---    2019.1
---
---
---```lua
---default = true
---```
---@field SA9004? boolean
---Trying to marshal a struct with no public fields nor custom marshaling
---
---The encoding/json and encoding/xml packages only operate on exported
---fields in structs, not unexported ones. It is usually an error to try
---to (un)marshal structs that only consist of unexported fields.
---
---This check will not flag calls involving types that define custom
---marshaling behavior, e.g. via MarshalJSON methods. It will also not
---flag empty structs.
---
---Available since
---    2019.2
---
---@field SA9005? boolean
---Dubious bit shifting of a fixed size integer value
---
---Bit shifting a value past its size will always clear the value.
---
---For instance:
---
---    v := int8(42)
---    v >>= 8
---
---will always result in 0.
---
---This check flags bit shifting operations on fixed size integer values only.
---That is, int, uint and uintptr are never flagged to avoid potential false
---positives in somewhat exotic but valid bit twiddling tricks:
---
---    // Clear any value above 32 bits if integers are more than 32 bits.
---    func f(i int) int {
---        v := i >> 32
---        v = v << 32
---        return i-v
---    }
---
---Available since
---    2020.2
---
---
---```lua
---default = true
---```
---@field SA9006? boolean
---Deleting a directory that shouldn't be deleted
---
---It is virtually never correct to delete system directories such as
---/tmp or the user's home directory. However, it can be fairly easy to
---do by mistake, for example by mistakenly using os.TempDir instead
---of ioutil.TempDir, or by forgetting to add a suffix to the result
---of os.UserHomeDir.
---
---Writing
---
---    d := os.TempDir()
---    defer os.RemoveAll(d)
---
---in your unit tests will have a devastating effect on the stability of your system.
---
---This check flags attempts at deleting the following directories:
---
---- os.TempDir
---- os.UserCacheDir
---- os.UserConfigDir
---- os.UserHomeDir
---
---Available since
---    2022.1
---
---@field SA9007? boolean
---else branch of a type assertion is probably not reading the right value
---
---When declaring variables as part of an if statement (like in 'if
---foo := ...; foo {'), the same variables will also be in the scope of
---the else branch. This means that in the following example
---
---    if x, ok := x.(int); ok {
---        // ...
---    } else {
---        fmt.Printf("unexpected type %T", x)
---    }
---
---x in the else branch will refer to the x from x, ok
---:=; it will not refer to the x that is being type-asserted. The
---result of a failed type assertion is the zero value of the type that
---is being asserted to, so x in the else branch will always have the
---value 0 and the type int.
---
---Available since
---    2022.1
---
---@field SA9008? boolean
---Ineffectual Go compiler directive
---
---A potential Go compiler directive was found, but is ineffectual as it begins
---with whitespace.
---
---Available since
---    2024.1
---
---
---```lua
---default = true
---```
---@field SA9009? boolean
---Returned function should be called in defer
---
---If you have a function such as:
---
---    func f() func() {
---        // Do something.
---        return func() {
---            // Do something.
---        }
---    }
---
---Then calling that in defer:
---
---    defer f()
---
---Is almost always a mistake, since you typically want to call the returned
---function:
---
---    defer f()()
---
---Available since
---    2026.2
---
---
---```lua
---default = true
---```
---@field SA9010? boolean
---Incorrect or missing package comment
---
---Packages must have a package comment that is formatted according to
---the guidelines laid out in
---https://go.dev/wiki/CodeReviewComments#package-comments.
---
---Available since
---    2019.1, non-default
---
---@field ST1000? boolean
---Dot imports are discouraged
---
---Dot imports that aren't in external test packages are discouraged.
---
---The dot_import_whitelist option can be used to whitelist certain
---imports.
---
---Quoting Go Code Review Comments:
---
---> The import . form can be useful in tests that, due to circular
---> dependencies, cannot be made part of the package being tested:
---> 
--->     package foo_test
---> 
--->     import (
--->         "bar/testutil" // also imports "foo"
--->         . "foo"
--->     )
---> 
---> In this case, the test file cannot be in package foo because it
---> uses bar/testutil, which imports foo. So we use the import .
---> form to let the file pretend to be part of package foo even though
---> it is not. Except for this one case, do not use import . in your
---> programs. It makes the programs much harder to read because it is
---> unclear whether a name like Quux is a top-level identifier in the
---> current package or in an imported package.
---
---Available since
---    2019.1
---
---Options
---    dot_import_whitelist
---
---@field ST1001? boolean
---Poorly chosen identifier
---
---Identifiers, such as variable and package names, follow certain rules.
---
---See the following links for details:
---
---- https://go.dev/doc/effective_go#package-names
---- https://go.dev/doc/effective_go#mixed-caps
---- https://go.dev/wiki/CodeReviewComments#initialisms
---- https://go.dev/wiki/CodeReviewComments#variable-names
---
---Available since
---    2019.1, non-default
---
---Options
---    initialisms
---
---@field ST1003? boolean
---Incorrectly formatted error string
---
---Error strings follow a set of guidelines to ensure uniformity and good
---composability.
---
---Quoting Go Code Review Comments:
---
---> Error strings should not be capitalized (unless beginning with
---> proper nouns or acronyms) or end with punctuation, since they are
---> usually printed following other context. That is, use
---> fmt.Errorf("something bad") not fmt.Errorf("Something bad"), so
---> that log.Printf("Reading %s: %v", filename, err) formats without a
---> spurious capital letter mid-message.
---
---Available since
---    2019.1
---
---@field ST1005? boolean
---Poorly chosen receiver name
---
---Quoting Go Code Review Comments:
---
---> The name of a method's receiver should be a reflection of its
---> identity; often a one or two letter abbreviation of its type
---> suffices (such as "c" or "cl" for "Client"). Don't use generic
---> names such as "me", "this" or "self", identifiers typical of
---> object-oriented languages that place more emphasis on methods as
---> opposed to functions. The name need not be as descriptive as that
---> of a method argument, as its role is obvious and serves no
---> documentary purpose. It can be very short as it will appear on
---> almost every line of every method of the type; familiarity admits
---> brevity. Be consistent, too: if you call the receiver "c" in one
---> method, don't call it "cl" in another.
---
---Available since
---    2019.1
---
---@field ST1006? boolean
---A function's error value should be its last return value
---
---A function's error value should be its last return value.
---
---Available since
---    2019.1
---
---@field ST1008? boolean
---Poorly chosen name for variable of type time.Duration
---
---time.Duration values represent an amount of time, which is represented
---as a count of nanoseconds. An expression like 5 * time.Microsecond
---yields the value 5000. It is therefore not appropriate to suffix a
---variable of type time.Duration with any time unit, such as Msec or
---Milli.
---
---Available since
---    2019.1
---
---@field ST1011? boolean
---Poorly chosen name for error variable
---
---Error variables that are part of an API should be called errFoo or
---ErrFoo.
---
---Available since
---    2019.1
---
---@field ST1012? boolean
---Should use constants for HTTP error codes, not magic numbers
---
---HTTP has a tremendous number of status codes. While some of those are
---well known (200, 400, 404, 500), most of them are not. The net/http
---package provides constants for all status codes that are part of the
---various specifications. It is recommended to use these constants
---instead of hard-coding magic numbers, to vastly improve the
---readability of your code.
---
---Available since
---    2019.1
---
---Options
---    http_status_code_whitelist
---
---@field ST1013? boolean
---A switch's default case should be the first or last case
---
---Available since
---    2019.1
---
---@field ST1015? boolean
---Use consistent method receiver names
---
---Available since
---    2019.1, non-default
---
---@field ST1016? boolean
---Don't use Yoda conditions
---
---Yoda conditions are conditions of the kind 'if 42 == x', where the
---literal is on the left side of the comparison. These are a common
---idiom in languages in which assignment is an expression, to avoid bugs
---of the kind 'if (x = 42)'. In Go, which doesn't allow for this kind of
---bug, we prefer the more idiomatic 'if x == 42'.
---
---Available since
---    2019.2
---
---@field ST1017? boolean
---Avoid zero-width and control characters in string literals
---
---Available since
---    2019.2
---
---@field ST1018? boolean
---Importing the same package multiple times
---
---Go allows importing the same package multiple times, as long as
---different import aliases are being used. That is, the following
---bit of code is valid:
---
---    import (
---        "fmt"
---        fumpt "fmt"
---        format "fmt"
---    )
---
---However, this is very rarely done on purpose. Usually, it is a
---sign of code that got refactored, accidentally adding duplicate
---import statements. It is also a rarely known feature, which may
---contribute to confusion.
---
---Do note that sometimes, this feature may be used
---intentionally (see for example
---https://github.com/golang/go/commit/3409ce39bfd7584523b7a8c150a310cea92d879d)
---– if you want to allow this pattern in your code base, you're
---advised to disable this check.
---
---It is acceptable to import the same package twice if one of the imports
---uses the blank identifier. This is allowed in order to increase
---resilience against erroneous changes when using the same package for its
---side effects as well as its exported API.
---
---Available since
---    2020.1
---
---@field ST1019? boolean
---The documentation of an exported function should start with the function's name
---
---Doc comments work best as complete sentences, which
---allow a wide variety of automated presentations. The first sentence
---should be a one-sentence summary that starts with the name being
---declared.
---
---If every doc comment begins with the name of the item it describes,
---you can use the doc subcommand of the go tool and run the output
---through grep.
---
---See https://go.dev/doc/effective_go#commentary for more
---information on how to write good documentation.
---
---Available since
---    2020.1, non-default
---
---@field ST1020? boolean
---The documentation of an exported type should start with type's name
---
---Doc comments work best as complete sentences, which
---allow a wide variety of automated presentations. The first sentence
---should be a one-sentence summary that starts with the name being
---declared.
---
---If every doc comment begins with the name of the item it describes,
---you can use the doc subcommand of the go tool and run the output
---through grep.
---
---See https://go.dev/doc/effective_go#commentary for more
---information on how to write good documentation.
---
---Available since
---    2020.1, non-default
---
---@field ST1021? boolean
---The documentation of an exported variable or constant should start with variable's name
---
---Doc comments work best as complete sentences, which
---allow a wide variety of automated presentations. The first sentence
---should be a one-sentence summary that starts with the name being
---declared.
---
---If every doc comment begins with the name of the item it describes,
---you can use the doc subcommand of the go tool and run the output
---through grep.
---
---See https://go.dev/doc/effective_go#commentary for more
---information on how to write good documentation.
---
---Available since
---    2020.1, non-default
---
---@field ST1022? boolean
---Redundant type in variable declaration
---
---Available since
---    2021.1, non-default
---
---@field ST1023? boolean
---replace interface{} with any
---
---The any analyzer suggests replacing uses of the empty interface type,
---`interface{}`, with the `any` alias, which was introduced in Go 1.18.
---This is a purely stylistic change that makes code more readable.
---
---```lua
---default = true
---```
---@field any? boolean
---simplify append chains using slices.Concat
---
---The appendclipped analyzer suggests replacing chains of append calls with a
---single call to slices.Concat, which was added in Go 1.21. For example,
---append(append(s, s1...), s2...) would be simplified to slices.Concat(s, s1, s2).
---
---In the simple case of appending to a newly allocated slice, such as
---append([]T(nil), s...), the analyzer suggests the more concise slices.Clone(s).
---For byte slices, it will prefer bytes.Clone if the "bytes" package is
---already imported.
---
---This fix is only applied when the base of the append tower is a
---"clipped" slice, meaning its length and capacity are equal (e.g.
---x[:0:0] or []T{}). This is to avoid changing program behavior by
---eliminating intended side effects on the base slice's underlying
---array.
---
---This analyzer is currently disabled by default as the
---transformation does not preserve the nilness of the base slice in
---all cases; see https://go.dev/issue/73557.
---@field appendclipped? boolean
---check for missing values after append
---
---This checker reports calls to append that pass
---no values to be appended to the slice.
---
---	s := []string{"a", "b", "c"}
---	_ = append(s)
---
---Such calls are always no-ops and often indicate an
---underlying mistake.
---
---```lua
---default = true
---```
---@field appends? boolean
---report mismatches between assembly files and Go declarations
---
---```lua
---default = true
---```
---@field asmdecl? boolean
---check for useless assignments
---
---This checker reports assignments of the form x = x or a[i] = a[i].
---These are almost always useless, and even when they aren't they are
---usually a mistake.
---
---```lua
---default = true
---```
---@field assign? boolean
---check for common mistakes using the sync/atomic package
---
---The atomic checker looks for assignment statements of the form:
---
---	x = atomic.AddUint64(&x, 1)
---
---which are not atomic.
---
---```lua
---default = true
---```
---@field atomic? boolean
---check for non-64-bits-aligned arguments to sync/atomic functions
---
---```lua
---default = true
---```
---@field atomicalign? boolean
---replace basic types in sync/atomic calls with atomic types
---
---The atomictypes analyzer suggests replacing the primitive sync/atomic functions with
---the strongly typed atomic wrapper types introduced in Go1.19 (e.g.
---atomic.Int32). For example,
---
---	var x int32
---	atomic.AddInt32(&x, 1)
---
---would become
---
---	var x atomic.Int32
---	x.Add(1)
---
---The atomic types are safer because they don't allow non-atomic access, which is
---a common source of bugs. These types also resolve memory alignment issues that
---plagued the old atomic functions on 32-bit architectures.
---
---```lua
---default = true
---```
---@field atomictypes? boolean
---replace for-range over b.N with b.Loop
---
---The bloop analyzer suggests replacing benchmark loops of the form
---`for i := 0; i < b.N; i++` or `for range b.N` with the more modern
---`for b.Loop()`, which was added in Go 1.24.
---
---This change makes benchmark code more readable and also removes the need for
---manual timer control, so any preceding calls to b.StartTimer, b.StopTimer,
---or b.ResetTimer within the same function will also be removed.
---
---Caveats: The b.Loop() method is designed to prevent the compiler from
---optimizing away the benchmark loop, which can occasionally result in
---slower execution due to increased allocations in some specific cases.
---Since its fix may change the performance of nanosecond-scale benchmarks,
---bloop is disabled by default in the `go fix` analyzer suite; see golang/go#74967.
---
---```lua
---default = true
---```
---@field bloop? boolean
---check for common mistakes involving boolean operators
---
---```lua
---default = true
---```
---@field bools? boolean
---check //go:build and // +build directives
---
---```lua
---default = true
---```
---@field buildtag? boolean
---detect some violations of the cgo pointer passing rules
---
---Check for invalid cgo pointer passing.
---This looks for code that uses cgo to call C code passing values
---whose types are almost always invalid according to the cgo pointer
---sharing rules.
---Specifically, it warns about attempts to pass a Go chan, map, func,
---or slice to C, either directly, or via a pointer, array, or struct.
---
---```lua
---default = true
---```
---@field cgocall? boolean
---check for unkeyed composite literals
---
---This analyzer reports a diagnostic for composite literals of struct
---types imported from another package that do not use the field-keyed
---syntax. Such literals are fragile because the addition of a new field
---(even if unexported) to the struct will cause compilation to fail.
---
---As an example,
---
---	err = &net.DNSConfigError{err}
---
---should be replaced by:
---
---	err = &net.DNSConfigError{Err: err}
---
---
---```lua
---default = true
---```
---@field composites? boolean
---check for locks erroneously passed by value
---
---Inadvertently copying a value containing a lock, such as sync.Mutex or
---sync.WaitGroup, may cause both copies to malfunction. Generally such
---values should be referred to through a pointer.
---
---```lua
---default = true
---```
---@field copylocks? boolean
---check for calls of reflect.DeepEqual on error values
---
---The deepequalerrors checker looks for calls of the form:
---
---    reflect.DeepEqual(err1, err2)
---
---where err1 and err2 are errors. Using reflect.DeepEqual to compare
---errors is discouraged.
---
---```lua
---default = true
---```
---@field deepequalerrors? boolean
---report common mistakes in defer statements
---
---The defers analyzer reports a diagnostic when a defer statement would
---result in a non-deferred call to time.Since, as experience has shown
---that this is nearly always a mistake.
---
---For example:
---
---	start := time.Now()
---	...
---	defer recordLatency(time.Since(start)) // error: call to time.Since is not deferred
---
---The correct code is:
---
---	defer func() { recordLatency(time.Since(start)) }()
---
---```lua
---default = true
---```
---@field defers? boolean
---check for use of deprecated identifiers
---
---The deprecated analyzer looks for deprecated symbols and package
---imports.
---
---See https://go.dev/wiki/Deprecated to learn about Go's convention
---for documenting and signaling deprecated identifiers.
---
---```lua
---default = true
---```
---@field deprecated? boolean
---check Go toolchain directives such as //go:debug
---
---This analyzer checks for problems with known Go toolchain directives
---in all Go source files in a package directory, even those excluded by
---//go:build constraints, and all non-Go source files too.
---
---For //go:debug (see https://go.dev/doc/godebug), the analyzer checks
---that the directives are placed only in Go source files, only above the
---package comment, and only in package main or *_test.go files.
---
---Support for other known directives may be added in the future.
---
---This analyzer does not check //go:build, which is handled by the
---buildtag analyzer.
---
---
---```lua
---default = true
---```
---@field directive? boolean
---check //go:embed directive usage
---
---This analyzer checks that the embed package is imported if //go:embed
---directives are present, providing a suggested fix to add the import if
---it is missing.
---
---This analyzer also checks that //go:embed directives precede the
---declaration of a single variable.
---
---```lua
---default = true
---```
---@field embed? boolean
---simplify references to embedded fields in composite literals
---
---The embedlit analyzer suggests removing redundant embedded field type specifiers
---from composite literals. Go1.27 introduced the ability to directly initialize
---fields promoted from embedded struct types without a nested literal. For
---example, given the following structs:
---
---	type T struct {
---		U
---	}
---
---	type U struct {
---		x int
---	}
---
---A composite literal such as
---
---	t := T{U: U{x: 1}}
---
---would become
---
---	t := T{x: 1}
---
---```lua
---default = true
---```
---@field embedlit? boolean
---report passing non-pointer or non-error values to errors.As
---
---The errorsas analyzer reports calls to errors.As where the type
---of the second argument is not a pointer to a type implementing error.
---For example:
---
---	var unwrappedErr net.DNSError
---	errors.As(err, unwrappedErr) // should use &unwrappedErr, DNSError.Error has a pointer receiver
---
---
---```lua
---default = true
---```
---@field errorsas? boolean
---replace errors.As with errors.AsType[T]
---
---This analyzer suggests fixes to simplify uses of [errors.As] of
---this form:
---
---	var myerr *MyErr
---	if errors.As(err, &myerr) {
---		handle(myerr)
---	}
---
---by using the less error-prone generic [errors.AsType] function,
---introduced in Go 1.26:
---
---	if myerr, ok := errors.AsType[*MyErr](err); ok {
---		handle(myerr)
---	}
---
---The fix is only offered if the var declaration has the form shown and
---there are no uses of myerr outside the if statement.
---
---```lua
---default = true
---```
---@field errorsastype? boolean
---report shadowing of errors.AsType[T] in if/else chains
---
---For example:
---
---	err := f()
---	if err, ok := errors.AsType[*FooErr](err); ok {
---	    useFoo(err)
---	} else if err, ok := errors.AsType[*BarErr](err); ok {
---	    useBar(err)
---	}
---
---In this case, the second call to errors.AsType does not operate on the
---original error. Instead, its operand is the zero value of type *FooErr
---produced by the first if statement; this is invariably a mistake.
---
---```lua
---default = true
---```
---@field errorsastypeshadow? boolean
---find structs that would use less memory if their fields were sorted
---
---This analyzer finds structs that can be rearranged to use less memory, and provides
---a suggested edit with the most compact order.
---
---Note that there are two different diagnostics reported. One checks struct size,
---and the other reports "pointer bytes" used. Pointer bytes is how many bytes of the
---object that the garbage collector has to potentially scan for pointers, for example:
---
---	struct { uint32; string }
---
---have 16 pointer bytes because the garbage collector has to scan up through the string's
---inner pointer.
---
---	struct { string; *uint32 }
---
---has 24 pointer bytes because it has to scan further through the *uint32.
---
---	struct { string; uint32 }
---
---has 8 because it can stop immediately after the string pointer.
---
---Be aware that the most compact order is not always the most efficient.
---In rare cases it may cause two variables each updated by its own goroutine
---to occupy the same CPU cache line, inducing a form of memory contention
---known as "false sharing" that slows down both goroutines.
---
---Unlike most analyzers, which report likely mistakes, the diagnostics
---produced by fieldanalyzer very rarely indicate a significant problem,
---so the analyzer is not included in typical suites such as vet or
---gopls. Use this standalone command to run it on your code:
---
---   $ go install golang.org/x/tools/go/analysis/passes/fieldalignment/cmd/fieldalignment@latest
---   $ fieldalignment [packages]
---
---
---@field fieldalignment? boolean
---suggest fixes for errors due to an incorrect number of return values
---
---This checker provides suggested fixes for type errors of the
---type "wrong number of return values (want %d, got %d)". For example:
---
---	func m() (int, string, *bool, error) {
---		return
---	}
---
---will turn into
---
---	func m() (int, string, *bool, error) {
---		return 0, "", nil, nil
---	}
---
---This functionality is similar to https://github.com/sqs/goreturns.
---
---```lua
---default = true
---```
---@field fillreturns? boolean
---replace []byte(fmt.Sprintf) with fmt.Appendf
---
---The fmtappendf analyzer suggests replacing `[]byte(fmt.Sprintf(...))` with
---`fmt.Appendf(nil, ...)`. This avoids the intermediate allocation of a string
---by Sprintf, making the code more efficient. The suggestion also applies to
---fmt.Sprint and fmt.Sprintln.
---
---Since its fix is not a Pareto improvement, fmtappendf is disabled by default in
---the `go fix` analyzer suite; see golang/go#77581.
---
---```lua
---default = true
---```
---@field fmtappendf? boolean
---remove redundant re-declaration of loop variables
---
---The forvar analyzer removes unnecessary shadowing of loop variables.
---Before Go 1.22, it was common to write `for _, x := range s { x := x ... }`
---to create a fresh variable for each iteration. Go 1.22 changed the semantics
---of `for` loops, making this pattern redundant. This analyzer removes the
---unnecessary `x := x` statement.
---
---This fix only applies to `range` loops.
---
---```lua
---default = true
---```
---@field forvar? boolean
---report assembly that clobbers the frame pointer before saving it
---
---```lua
---default = true
---```
---@field framepointer? boolean
---check format of addresses passed to net.Dial
---
---This analyzer flags code that produce network address strings using
---fmt.Sprintf, as in this example:
---
---    addr := fmt.Sprintf("%s:%d", host, 12345) // "will not work with IPv6"
---    ...
---    conn, err := net.Dial("tcp", addr)       // "when passed to dial here"
---
---The analyzer suggests a fix to use the correct approach, a call to
---net.JoinHostPort:
---
---    addr := net.JoinHostPort(host, "12345")
---    ...
---    conn, err := net.Dial("tcp", addr)
---
---A similar diagnostic and fix are produced for a format string of "%s:%s".
---
---
---```lua
---default = true
---```
---@field hostport? boolean
---check for mistakes using HTTP responses
---
---A common mistake when using the net/http package is to defer a function
---call to close the http.Response Body before checking the error that
---determines whether the response is valid:
---
---	resp, err := http.Head(url)
---	defer resp.Body.Close()
---	if err != nil {
---		log.Fatal(err)
---	}
---	// (defer statement belongs here)
---
---This checker helps uncover latent nil dereference bugs by reporting a
---diagnostic for such mistakes.
---
---```lua
---default = true
---```
---@field httpresponse? boolean
---detect impossible interface-to-interface type assertions
---
---This checker flags type assertions v.(T) and corresponding type-switch cases
---in which the static type V of v is an interface that cannot possibly implement
---the target interface T. This occurs when V and T contain methods with the same
---name but different signatures. Example:
---
---	var v interface {
---		Read()
---	}
---	_ = v.(io.Reader)
---
---The Read method in v has a different signature than the Read method in
---io.Reader, so this assertion cannot succeed.
---
---```lua
---default = true
---```
---@field ifaceassert? boolean
---check for unnecessary type arguments in call expressions
---
---Explicit type arguments may be omitted from call expressions if they can be
---inferred from function arguments, or from other type arguments:
---
---	func f[T any](T) {}
---	
---	func _() {
---		f[string]("foo") // string could be inferred
---	}
---
---
---```lua
---default = true
---```
---@field infertypeargs? boolean
---apply fixes based on 'go:fix inline' comment directives
---
---The inline analyzer inlines functions, constants, and type aliases
---that are marked for inlining.
---
---Use this command to apply (just) inline fixes en masse:
---
---	$ go fix -inline ./...
---
---## Functions
---
---Given a function that is marked for inlining, like this one:
---
---	//go:fix inline
---	func Square(x int) int { return Pow(x, 2) }
---
---this analyzer will recommend that calls to the function elsewhere, in the same
---or other packages, should be inlined.
---
---Inlining can be used to move off of a deprecated function:
---
---	// Deprecated: prefer Pow(x, 2).
---	//go:fix inline
---	func Square(x int) int { return Pow(x, 2) }
---
---It can also be used to move off of an obsolete package,
---as when the import path has changed or a higher major version is available:
---
---	package pkg
---
---	import pkg2 "pkg/v2"
---
---	//go:fix inline
---	func F() { pkg2.F(nil) }
---
---Replacing a call pkg.F() by pkg2.F(nil) can have no effect on the program,
---so this mechanism provides a low-risk way to update large numbers of calls.
---We recommend, where possible, expressing the old API in terms of the new one
---to enable automatic migration.
---
---The inliner takes care to avoid behavior changes, even subtle ones,
---such as changes to the order in which argument expressions are
---evaluated. When it cannot safely eliminate all parameter variables,
---it may introduce a "binding declaration" of the form
---
---	var params = args
---
---to evaluate argument expressions in the correct order and bind them to
---parameter variables. Since the resulting code transformation may be
---stylistically suboptimal, such inlinings may be disabled by specifying
---the -inline.allow_binding_decl=false flag to the analyzer driver.
---
---(In cases where it is not safe to "reduce" a call—that is, to replace
---a call f(x) by the body of function f, suitably substituted—the
---inliner machinery is capable of replacing f by a function literal,
---func(){...}(). However, the inline analyzer discards all such
---"literalizations" unconditionally, again on grounds of style.)
---
---## Constants
---
---Given a constant that is marked for inlining, like this one:
---
---	//go:fix inline
---	const Ptr = Pointer
---
---this analyzer will recommend that uses of Ptr should be replaced with Pointer.
---
---As with functions, inlining can be used to replace deprecated constants and
---constants in obsolete packages.
---
---A constant definition can be marked for inlining only if it refers to another
---named constant.
---
---The "//go:fix inline" comment must appear before a single const declaration on its own,
---as above; before a const declaration that is part of a group, as in this case:
---
---	const (
---	   C = 1
---	   //go:fix inline
---	   Ptr = Pointer
---	)
---
---or before a group, applying to every constant in the group:
---
---	//go:fix inline
---	const (
---		Ptr = Pointer
---		Val = Value
---	)
---
---## Type aliases
---
---Similar to named constants, a type alias can also be marked for inlining:
---
---	//go:fix inline
---	type A = newpkg.A
---
---The analyzer will replace all references to the annotated type
---(A) by the type on the right-hand side of the declaration (newpkg.A).
---
---## Tests
---
---A use of a function, named constant, or type alias X from its
---dedicated test (TestX), is not inlined, since the purpose of the test
---is to exercise X itself, even if it is deprecated and other uses of it
---should be inlined.
---This applies to benchmarks and examples too, and follows the usual
---conventions of test function naming.
---
---Similarly, if the symbol X is declared in a file named foo.go, any use
---of it within a file named foo_test.go will also not be inlined.
---
---```lua
---default = true
---```
---@field inline? boolean
---check references to loop variables from within nested functions
---
---This analyzer reports places where a function literal references the
---iteration variable of an enclosing loop, and the loop calls the function
---in such a way (e.g. with go or defer) that it may outlive the loop
---iteration and possibly observe the wrong value of the variable.
---
---Note: An iteration variable can only outlive a loop iteration in Go versions <=1.21.
---In Go 1.22 and later, the loop variable lifetimes changed to create a new
---iteration variable per loop iteration. (See go.dev/issue/60078.)
---
---In this example, all the deferred functions run after the loop has
---completed, so all observe the final value of v [<go1.22].
---
---	for _, v := range list {
---	    defer func() {
---	        use(v) // incorrect
---	    }()
---	}
---
---One fix is to create a new variable for each iteration of the loop:
---
---	for _, v := range list {
---	    v := v // new var per iteration
---	    defer func() {
---	        use(v) // ok
---	    }()
---	}
---
---After Go version 1.22, the previous two for loops are equivalent
---and both are correct.
---
---The next example uses a go statement and has a similar problem [<go1.22].
---In addition, it has a data race because the loop updates v
---concurrent with the goroutines accessing it.
---
---	for _, v := range elem {
---	    go func() {
---	        use(v)  // incorrect, and a data race
---	    }()
---	}
---
---A fix is the same as before. The checker also reports problems
---in goroutines started by golang.org/x/sync/errgroup.Group.
---A hard-to-spot variant of this form is common in parallel tests:
---
---	func Test(t *testing.T) {
---	    for _, test := range tests {
---	        t.Run(test.name, func(t *testing.T) {
---	            t.Parallel()
---	            use(test) // incorrect, and a data race
---	        })
---	    }
---	}
---
---The t.Parallel() call causes the rest of the function to execute
---concurrent with the loop [<go1.22].
---
---The analyzer reports references only in the last statement,
---as it is not deep enough to understand the effects of subsequent
---statements that might render the reference benign.
---("Last statement" is defined recursively in compound
---statements such as if, switch, and select.)
---
---See: https://golang.org/doc/go_faq.html#closures_and_goroutines
---
---```lua
---default = true
---```
---@field loopclosure? boolean
---check cancel func returned by context.WithCancel is called
---
---The cancellation function returned by context.WithCancel, WithTimeout,
---WithDeadline and variants such as WithCancelCause must be called,
---or the new context will remain live until its parent context is cancelled.
---(The background context is never cancelled.)
---
---```lua
---default = true
---```
---@field lostcancel? boolean
---checks for unnecessary calls to maps.Keys and maps.Values in range statements
---
---Consider a loop written like this:
---
---	for val := range maps.Values(m) {
---		fmt.Println(val)
---	}
---
---This should instead be written without the call to maps.Values:
---
---	for _, val := range m {
---		fmt.Println(val)
---	}
---
---golang.org/x/exp/maps returns slices for Keys/Values instead of iterators,
---but unnecessary calls should similarly be removed:
---
---	for _, key := range maps.Keys(m) {
---		fmt.Println(key)
---	}
---
---should be rewritten as:
---
---	for key := range m {
---		fmt.Println(key)
---	}
---
---```lua
---default = true
---```
---@field maprange? boolean
---replace explicit loops over maps with calls to maps package
---
---The mapsloop analyzer replaces loops of the form
---
---	for k, v := range x { m[k] = v }
---
---with a single call to a function from the `maps` package, added in Go 1.23.
---Depending on the context, this could be `maps.Copy`, `maps.Insert`,
---`maps.Clone`, or `maps.Collect`.
---
---The transformation to `maps.Clone` is applied conservatively, as it
---preserves the nilness of the source map, which may be a subtle change in
---behavior if the original code did not handle a nil map in the same way.
---
---```lua
---default = true
---```
---@field mapsloop? boolean
---replace if/else statements with calls to min or max
---
---The minmax analyzer simplifies conditional assignments by suggesting the use
---of the built-in `min` and `max` functions, introduced in Go 1.21. For example,
---
---	if a < b { x = a } else { x = b }
---
---is replaced by
---
---	x = min(a, b).
---
---This analyzer avoids making suggestions for floating-point types,
---as the behavior of `min` and `max` with NaN values can differ from
---the original if/else statement.
---
---```lua
---default = true
---```
---@field minmax? boolean
---simplify code by using go1.26's new(expr)
---
---This analyzer finds declarations of functions of this form:
---
---	func varOf(x int) *int { return &x }
---
---and suggests a fix to turn them into inlinable wrappers around
---go1.26's built-in new(expr) function:
---
---	//go:fix inline
---	func varOf(x int) *int { return new(x) }
---
---(The directive comment causes the 'inline' analyzer to suggest
---that calls to such functions are inlined.)
---
---In addition, this analyzer suggests a fix for each call
---to one of the functions before it is transformed, so that
---
---	use(varOf(123))
---
---is replaced by:
---
---	use(new(123))
---
---Wrapper functions such as varOf are common when working with Go
---serialization packages such as for JSON or protobuf, where pointers
---are often used to express optionality.
---
---```lua
---default = true
---```
---@field newexpr? boolean
---check for useless comparisons between functions and nil
---
---A useless comparison is one like f == nil as opposed to f() == nil.
---
---```lua
---default = true
---```
---@field nilfunc? boolean
---check for redundant or impossible nil comparisons
---
---The nilness checker inspects the control-flow graph of each function in
---a package and reports nil pointer dereferences, degenerate nil
---pointers, and panics with nil values. A degenerate comparison is of the form
---x==nil or x!=nil where x is statically known to be nil or non-nil. These are
---often a mistake, especially in control flow related to errors. Panics with nil
---values are checked because they are not detectable by
---
---	if r := recover(); r != nil {
---
---This check reports conditions such as:
---
---	if f == nil { // impossible condition (f is a function)
---	}
---
---and:
---
---	p := &v
---	...
---	if p != nil { // tautological condition
---	}
---
---and:
---
---	if p == nil {
---		print(*p) // nil dereference
---	}
---
---and:
---
---	if p == nil {
---		panic(p)
---	}
---
---Sometimes the control flow may be quite complex, making bugs hard
---to spot. In the example below, the err.Error expression is
---guaranteed to panic because, after the first return, err must be
---nil. The intervening loop is just a distraction.
---
---	...
---	err := g.Wait()
---	if err != nil {
---		return err
---	}
---	partialSuccess := false
---	for _, err := range errs {
---		if err == nil {
---			partialSuccess = true
---			break
---		}
---	}
---	if partialSuccess {
---		reportStatus(StatusMessage{
---			Code:   code.ERROR,
---			Detail: err.Error(), // "nil dereference in dynamic method call"
---		})
---		return nil
---	}
---
---...
---
---```lua
---default = true
---```
---@field nilness? boolean
---suggested fixes for "no new vars on left side of :="
---
---This checker provides suggested fixes for type errors of the
---type "no new vars on left side of :=". For example:
---
---	z := 1
---	z := 2
---
---will turn into
---
---	z := 1
---	z = 2
---
---```lua
---default = true
---```
---@field nonewvars? boolean
---suggested fixes for unexpected return values
---
---This checker provides suggested fixes for type errors of the
---type "no result values expected" or "too many return values".
---For example:
---
---	func z() { return nil }
---
---will turn into
---
---	func z() { return }
---
---```lua
---default = true
---```
---@field noresultvalues? boolean
---suggest replacing omitempty with omitzero for struct fields
---
---The omitzero analyzer identifies uses of the `omitempty` JSON struct
---tag on fields that are themselves structs. For struct-typed fields,
---the `omitempty` tag has no effect on the behavior of json.Marshal and
---json.Unmarshal. The analyzer offers two suggestions: either remove the
---tag, or replace it with `omitzero` (added in Go 1.24), which correctly
---omits the field if the struct value is zero.
---
---However, some other serialization packages (notably kubebuilder, see
---https://book.kubebuilder.io/reference/markers.html) may have their own
---interpretation of the `json:",omitzero"` tag, so removing it may affect
---program behavior. For this reason, the omitzero modernizer will not
---make changes in any package that contains +kubebuilder annotations.
---
---Replacing `omitempty` with `omitzero` is a change in behavior. The
---original code would always encode the struct field, whereas the
---modified code will omit it if it is a zero-value.
---
---```lua
---default = true
---```
---@field omitzero? boolean
---remove obsolete //+build comments
---
---The plusbuild analyzer suggests a fix to remove obsolete build tags
---of the form:
---
---	//+build linux,amd64
---
---in files that also contain a Go 1.18-style tag such as:
---
---	//go:build linux && amd64
---
---(It does not check that the old and new tags are consistent;
---that is the job of the 'buildtag' analyzer in the vet suite.)
---
---```lua
---default = true
---```
---@field plusbuild? boolean
---check consistency of Printf format strings and arguments
---
---The check applies to calls of the formatting functions such as
---[fmt.Printf] and [fmt.Sprintf], as well as any detected wrappers of
---those functions such as [log.Printf]. It reports a variety of
---mistakes such as syntax errors in the format string and mismatches
---(of number and type) between the verbs and their arguments.
---
---See the documentation of the fmt package for the complete set of
---format operators and their operand types.
---
---```lua
---default = true
---```
---@field printf? boolean
---replace 3-clause for loops with for-range over integers
---
---The rangeint analyzer suggests replacing traditional for loops such
---as
---
---	for i := 0; i < n; i++ { ... }
---
---with the more idiomatic Go 1.22 style:
---
---	for i := range n { ... }
---
---This transformation is applied only if (a) the loop variable is not
---modified within the loop body and (b) the loop's limit expression
---is not modified within the loop, as `for range` evaluates its
---operand only once.
---
---```lua
---default = true
---```
---@field rangeint? boolean
---check for inefficient recursive iterators
---
---This analyzer reports when a function that returns an iterator
---(iter.Seq or iter.Seq2) calls itself as the operand of a range
---statement, as this is inefficient.
---
---When implementing an iterator (e.g. iter.Seq[T]) for a recursive
---data type such as a tree or linked list, it is tempting to
---recursively range over the iterator for each child element.
---
---Here's an example of a naive iterator over a binary tree:
---
---	type tree struct {
---		value       int
---		left, right *tree
---	}
---
---	func (t *tree) All() iter.Seq[int] {
---		return func(yield func(int) bool) {
---			if t != nil {
---				for elem := range t.left.All() { // "inefficient recursive iterator"
---					if !yield(elem) {
---						return
---					}
---				}
---				if !yield(t.value) {
---					return
---				}
---				for elem := range t.right.All() { // "inefficient recursive iterator"
---					if !yield(elem) {
---						return
---					}
---				}
---			}
---		}
---	}
---
---Though it correctly enumerates the elements of the tree, it hides a
---significant performance problem--two, in fact. Consider a balanced
---tree of N nodes. Iterating the root node will cause All to be
---called once on every node of the tree. This results in a chain of
---nested active range-over-func statements when yield(t.value) is
---called on a leaf node.
---
---The first performance problem is that each range-over-func
---statement must typically heap-allocate a variable, so iteration of
---the tree allocates as many variables as there are elements in the
---tree, for a total of O(N) allocations, all unnecessary.
---
---The second problem is that each call to yield for a leaf of the
---tree causes each of the enclosing range loops to receive a value,
---which they then immediately pass on to their respective yield
---function. This results in a chain of log(N) dynamic yield calls per
---element, a total of O(N*log N) dynamic calls overall, when only
---O(N) are necessary.
---
---A better implementation strategy for recursive iterators is to
---first define the "every" operator for your recursive data type,
---where every(f) reports whether an arbitrary predicate f(x) is true
---for every element x in the data type. For our tree, the every
---function would be:
---
---	func (t *tree) every(f func(int) bool) bool {
---		return t == nil ||
---			t.left.every(f) && f(t.value) && t.right.every(f)
---	}
---
---For example, this use of the every operator prints whether every
---element in the tree is an even number:
---
---	even := func(x int) bool { return x&1 == 0 }
---	println(t.every(even))
---
---Then the iterator can be simply expressed as a trivial wrapper
---around the every operator:
---
---	func (t *tree) All() iter.Seq[int] {
---		return func(yield func(int) bool) {
---			_ = t.every(yield)
---		}
---	}
---
---In effect, tree.All computes whether yield returns true for each
---element, short-circuiting if it ever returns false, then discards
---the final boolean result.
---
---This has much better performance characteristics: it makes one
---dynamic call per element of the tree, and it doesn't heap-allocate
---anything. It is also clearer.
---
---```lua
---default = true
---```
---@field recursiveiter? boolean
---replace reflect.TypeOf(x) with TypeFor[T]()
---
---This analyzer suggests fixes to replace uses of reflect.TypeOf(x) with
---reflect.TypeFor, introduced in go1.22, when the desired runtime type
---is known at compile time, for example:
---
---	reflect.TypeOf(uint32(0))        -> reflect.TypeFor[uint32]()
---	reflect.TypeOf((*ast.File)(nil)) -> reflect.TypeFor[*ast.File]()
---
---It also offers a fix to simplify the constructions below, which use
---reflect.TypeOf to return the runtime type for an interface type,
---
---	reflect.TypeOf((*io.Reader)(nil)).Elem()
---
---or:
---
---	reflect.TypeOf([]io.Reader(nil)).Elem()
---
---to:
---
---	reflect.TypeFor[io.Reader]()
---
---No fix is offered in cases when the runtime type is dynamic, such as:
---
---	var r io.Reader = ...
---	reflect.TypeOf(r)
---
---or when the operand has potential side effects.
---
---```lua
---default = true
---```
---@field reflecttypefor? boolean
---scannererr: report failure to check bufio.Scanner.Err
---
---This analyzer reports uses of bufio.Scanner in which the result of
---NewScanner is assigned to a local variable that is then used in a loop
---that calls Scanner.Scan, but lacks a final check of Scanner.Err,
---which is how I/O errors are reported.
---
---For example:
---
---	sc := bufio.NewScanner(os.Stdin) // error: "bufio.Scanner sc is used in Scan loop without final check of sc.Err()"
---	for sc.Scan() {
---		line := sc.Text()
---		use(line)
---	}
---	/* ...no use of sc.Err()... */
---
---To avoid false positives, the analyzer is silent if the scanner is
---passed into or out of the function or assigned somewhere other than a
---local variable.
---
---It is not this analyzer's goal to ensure proper handling of errors in
---all cases, but merely the simple mistakes where the user may have been
---oblivious to the existence of the Scanner.Err method.
---
---The analyzer ignores calls to bufio.NewScanner whose argument is an
---infallible memory-backed io.Reader such as strings.Reader or bytes.Buffer.
---(In such cases, Scan may yet fail if a token or line is too long for the
---scanner's internal buffer, but this is rare.)
---
---If you know that errors are impossible for a given scanner, you can
---suppress the diagnostic thus:
---
---	_ = sc.Err() // ignore error; neither reading nor scanning can fail
---
---
---
---```lua
---default = true
---```
---@field scannererr? boolean
---check for possible unintended shadowing of variables
---
---This analyzer check for shadowed variables.
---A shadowed variable is a variable declared in an inner scope
---with the same name and type as a variable in an outer scope,
---and where the outer variable is mentioned after the inner one
---is declared.
---
---(This definition can be refined; the module generates too many
---false positives and is not yet enabled by default.)
---
---For example:
---
---	func BadRead(f *os.File, buf []byte) error {
---		var err error
---		for {
---			n, err := f.Read(buf) // shadows the function variable 'err'
---			if err != nil {
---				break // causes return of wrong value
---			}
---			foo(buf)
---		}
---		return err
---	}
---@field shadow? boolean
---check for shifts that equal or exceed the width of the integer
---
---```lua
---default = true
---```
---@field shift? boolean
---check for unbuffered channel of os.Signal
---
---This checker reports call expression of the form
---
---	signal.Notify(c <-chan os.Signal, sig ...os.Signal),
---
---where c is an unbuffered channel, which can be at risk of missing the signal.
---
---```lua
---default = true
---```
---@field sigchanyzer? boolean
---check for composite literal simplifications
---
---An array, slice, or map composite literal of the form:
---
---	[]T{T{}, T{}}
---
---will be simplified to:
---
---	[]T{{}, {}}
---
---This is one of the simplifications that "gofmt -s" applies.
---
---This analyzer ignores generated code.
---
---```lua
---default = true
---```
---@field simplifycompositelit? boolean
---check for range statement simplifications
---
---A range of the form:
---
---	for x, _ = range v {...}
---
---will be simplified to:
---
---	for x = range v {...}
---
---A range of the form:
---
---	for _ = range v {...}
---
---will be simplified to:
---
---	for range v {...}
---
---This is one of the simplifications that "gofmt -s" applies.
---
---This analyzer ignores generated code.
---
---```lua
---default = true
---```
---@field simplifyrange? boolean
---check for slice simplifications
---
---A slice expression of the form:
---
---	s[a:len(s)]
---
---will be simplified to:
---
---	s[a:]
---
---This is one of the simplifications that "gofmt -s" applies.
---
---This analyzer ignores generated code.
---
---```lua
---default = true
---```
---@field simplifyslice? boolean
---replace backward loops over slices with slices.Backward
---
---The slicesbackward analyzer suggests replacing manually-written backward
---loops of the form
---
---	for i := len(s) - 1; i >= 0; i-- {
---	    use(s[i])
---	}
---
---with the more readable Go 1.23 style using slices.Backward:
---
---	for _, v := range slices.Backward(s) {
---	    use(v)
---	}
---
---If the loop index is needed beyond just indexing into the slice, both
---the index and value variables are kept:
---
---	for i, v := range slices.Backward(s) { ... }
---
---```lua
---default = true
---```
---@field slicesbackward? boolean
---replace loops with slices.Contains or slices.ContainsFunc
---
---The slicescontains analyzer simplifies loops that check for the existence of
---an element in a slice. It replaces them with calls to `slices.Contains` or
---`slices.ContainsFunc`, which were added in Go 1.21.
---
---If the expression for the target element has side effects, this
---transformation will cause those effects to occur only once, not
---once per tested slice element.
---
---```lua
---default = true
---```
---@field slicescontains? boolean
---replace append-based slice deletion with slices.Delete
---
---The slicesdelete analyzer suggests replacing the idiom
---
---	s = append(s[:i], s[j:]...)
---
---with the more explicit
---
---	s = slices.Delete(s, i, j)
---
---introduced in Go 1.21.
---
---This analyzer is disabled by default. The `slices.Delete` function
---zeros the elements between the new length and the old length of the
---slice to prevent memory leaks, which is a subtle difference in
---behavior compared to the append-based idiom; see https://go.dev/issue/73686.
---@field slicesdelete? boolean
---replace sort.Slice with slices.Sort for basic types
---
---The slicessort analyzer simplifies sorting slices of basic ordered
---types. It replaces
---
---	sort.Slice(s, func(i, j int) bool { return s[i] < s[j] })
---
---with the simpler `slices.Sort(s)`, which was added in Go 1.21.
---
---```lua
---default = true
---```
---@field slicessort? boolean
---check for invalid structured logging calls
---
---The slog checker looks for calls to functions from the log/slog
---package that take alternating key-value pairs. It reports calls
---where an argument in a key position is neither a string nor a
---slog.Attr, and where a final key is missing its value.
---For example,it would report
---
---	slog.Warn("message", 11, "k") // slog.Warn arg "11" should be a string or a slog.Attr
---
---and
---
---	slog.Info("message", "k1", v1, "k2") // call to slog.Info missing a final value
---
---```lua
---default = true
---```
---@field slog? boolean
---check the argument type of sort.Slice
---
---sort.Slice requires an argument of a slice type. Check that
---the interface{} value passed to sort.Slice is actually a slice.
---
---```lua
---default = true
---```
---@field sortslice? boolean
---sqlrowserr: report failure to check sql.Rows.Err
---
---This analyzer reports uses of sql.Rows in which the result of a query
---such as db.Query() is assigned to a local variable that is then used
---in a loop that calls Rows.Next, but lacks a final check of Rows.Err.
---This causes row iteration errors to be discarded.
---
---For example:
---
---	rows, err := db.Query("select ...") // error: "sql.Rows rows is used in Next loop without final check of rows.Err()"
---	if err != nil {
---		return err
---	}
---	defer rows.Close() // ignore error
---	for rows.Next() {
---		var x int
---		if err := rows.Scan(&x); err != nil {
---			return err
---		}
---		use(x)
---	}
---	/* ...no use of rows.Err()... */
---
---Correct usage of sql.Rows demands both a call to Rows.Close to release
---resources and a call to Rows.Err to report iteration errors. It is
---not critical to report resource cleanup errors, but it is crucial to
---report iteration errors as they would otherwise be indistinguishable
---from a smaller result.
---
---To avoid false positives, the analyzer is silent if the Rows is passed
---into or out of the function or assigned somewhere other than a local
---variable.
---
---It is not this analyzer's goal to ensure proper handling of errors in
---all cases, but merely the simple mistakes where the user may have been
---oblivious to the existence of the Rows.Err method.
---
---
---```lua
---default = true
---```
---@field sqlrowserr? boolean
---use iterators instead of Len/At-style APIs
---
---This analyzer suggests a fix to replace each loop of the form:
---
---	for i := 0; i < x.Len(); i++ {
---		use(x.At(i))
---	}
---
---or its "for elem := range x.Len()" equivalent by a range loop over an
---iterator offered by the same data type:
---
---	for elem := range x.All() {
---		use(x.At(i)
---	}
---
---where x is one of various well-known types in the standard library.
---
---```lua
---default = true
---```
---@field stditerators? boolean
---check signature of methods of well-known interfaces
---
---Sometimes a type may be intended to satisfy an interface but may fail to
---do so because of a mistake in its method signature.
---For example, the result of this WriteTo method should be (int64, error),
---not error, to satisfy io.WriterTo:
---
---	type myWriterTo struct{...}
---	func (myWriterTo) WriteTo(w io.Writer) error { ... }
---
---This check ensures that each method whose name matches one of several
---well-known interface methods from the standard library has the correct
---signature for that interface.
---
---Checked method names include:
---
---	Format GobEncode GobDecode MarshalJSON MarshalXML
---	Peek ReadByte ReadFrom ReadRune Scan Seek
---	UnmarshalJSON UnreadByte UnreadRune WriteByte
---	WriteTo
---
---```lua
---default = true
---```
---@field stdmethods? boolean
---report uses of too-new standard library symbols
---
---The stdversion analyzer reports references to symbols in the standard
---library that were introduced by a Go release higher than the one in
---force in the referring file. (Recall that the file's Go version is
---defined by the 'go' directive its module's go.mod file, or by a
---"//go:build go1.X" build tag at the top of the file.)
---
---The analyzer does not report a diagnostic for a reference to a "too
---new" field or method of a type that is itself "too new", as this may
---have false positives, for example if fields or methods are accessed
---through a type alias that is guarded by a Go version constraint.
---
---
---```lua
---default = true
---```
---@field stdversion? boolean
---check for string(int) conversions
---
---This checker flags conversions of the form string(x) where x is an integer
---(but not byte or rune) type. Such conversions are discouraged because they
---return the UTF-8 representation of the Unicode code point x, and not a decimal
---string representation of x as one might expect. Furthermore, if x denotes an
---invalid code point, the conversion cannot be statically rejected.
---
---For conversions that intend on using the code point, consider replacing them
---with string(rune(x)). Otherwise, strconv.Itoa and its equivalents return the
---string representation of the value in the desired base.
---
---```lua
---default = true
---```
---@field stringintconv? boolean
---replace += with strings.Builder
---
---This analyzer replaces repeated string += string concatenation
---operations with calls to Go 1.10's strings.Builder.
---
---For example:
---
---	var s = "["
---	for x := range seq {
---		s += x
---		s += "."
---	}
---	s += "]"
---	use(s)
---
---is replaced by:
---
---	var s strings.Builder
---	s.WriteString("[")
---	for x := range seq {
---		s.WriteString(x)
---		s.WriteString(".")
---	}
---	s.WriteString("]")
---	use(s.String())
---
---This avoids quadratic memory allocation and improves performance.
---
---No diagnostics are issued in tests, where data sizes are often
---small and asymptotic performance is not a security concern.
---
---The analyzer requires that all references to s before the final uses
---are += operations. To avoid warning about trivial cases, at least one
---must appear within a loop. The variable s must be a local
---variable, not a global or parameter.
---
---All uses of the finished string must come after the last += operation.
---Each such use will be replaced by a call to strings.Builder's String method.
---(These may appear within an intervening loop or function literal, since even
---if s.String() is called repeatedly, it does not allocate memory.)
---
---Often the addend is a call to fmt.Sprintf, as in this example:
---
---	var s string
---	for x := range seq {
---		s += fmt.Sprintf("%v", x)
---	}
---
---which, once the suggested fix is applied, becomes:
---
---	var s strings.Builder
---	for x := range seq {
---		s.WriteString(fmt.Sprintf("%v", x))
---	}
---
---The WriteString call can be further simplified to the more efficient
---fmt.Fprintf(&s, "%v", x), avoiding the allocation of an intermediary.
---However, stringsbuilder does not perform this simplification;
---it requires staticcheck analyzer QF1012. (See https://go.dev/issue/76918.)
---
---```lua
---default = true
---```
---@field stringsbuilder? boolean
---replace strings.Index etc. with strings.Cut
---
---This analyzer replaces certain patterns of use of [strings.Index] and string slicing by [strings.Cut], added in go1.18.
---
---For example:
---
---	idx := strings.Index(s, substr)
---	if idx >= 0 {
---	    return s[:idx]
---	}
---
---is replaced by:
---
---	before, _, ok := strings.Cut(s, substr)
---	if ok {
---	    return before
---	}
---
---And:
---
---	idx := strings.Index(s, substr)
---	if idx >= 0 {
---	    return
---	}
---
---is replaced by:
---
---	found := strings.Contains(s, substr)
---	if found {
---	    return
---	}
---
---It also handles variants using [strings.IndexByte] instead of Index, or the bytes package instead of strings.
---
---Fixes are offered only in cases in which there are no potential modifications of the idx, s, or substr expressions between their definition and use.
---
---It also replaces [strings.SplitN](s, sep, 2)[0] and [strings.Split](s, sep)[0] with the "before" result of strings.Cut, when sep is a non-empty string constant:
---
---	x := strings.SplitN(s, sep, 2)[0]
---
---is replaced by:
---
---	x, _, _ := strings.Cut(s, sep)
---
---The fix is only offered when sep is a non-empty string literal. When sep is a variable or the empty string, the semantics differ (strings.Split(s, "")[0] returns the first character of s, but strings.Cut(s, "").before is ""), so no fix is suggested.
---
---```lua
---default = true
---```
---@field stringscut? boolean
---replace HasPrefix/TrimPrefix with CutPrefix
---
---The stringscutprefix analyzer simplifies a common pattern where code first
---checks for a prefix with `strings.HasPrefix` and then removes it with
---`strings.TrimPrefix`. It replaces this two-step process with a single call
---to `strings.CutPrefix`, introduced in Go 1.20. The analyzer also handles
---the equivalent functions in the `bytes` package.
---
---For example, this input:
---
---	if strings.HasPrefix(s, prefix) {
---	    use(strings.TrimPrefix(s, prefix))
---	}
---
---is fixed to:
---
---	if after, ok := strings.CutPrefix(s, prefix); ok {
---	    use(after)
---	}
---
---The analyzer also offers fixes to use CutSuffix in a similar way.
---This input:
---
---	if strings.HasSuffix(s, suffix) {
---	    use(strings.TrimSuffix(s, suffix))
---	}
---
---is fixed to:
---
---	if before, ok := strings.CutSuffix(s, suffix); ok {
---	    use(before)
---	}
---
---```lua
---default = true
---```
---@field stringscutprefix? boolean
---replace ranging over Split/Fields with SplitSeq/FieldsSeq
---
---The stringsseq analyzer improves the efficiency of iterating over substrings.
---It replaces
---
---	for range strings.Split(...)
---
---with the more efficient
---
---	for range strings.SplitSeq(...)
---
---which was added in Go 1.24 and avoids allocating a slice for the
---substrings. The analyzer also handles strings.Fields and the
---equivalent functions in the bytes package.
---
---```lua
---default = true
---```
---@field stringsseq? boolean
---check that struct field tags conform to reflect.StructTag.Get
---
---Also report certain struct tags (json, xml) used with unexported fields.
---
---```lua
---default = true
---```
---@field structtag? boolean
---replace context.WithCancel with t.Context in tests
---
---The testingcontext analyzer simplifies context management in tests. It
---replaces the manual creation of a cancellable context,
---
---	ctx, cancel := context.WithCancel(context.Background())
---	defer cancel()
---
---with a single call to t.Context(), which was added in Go 1.24.
---
---This change is only suggested if the `cancel` function is not used
---for any other purpose.
---
---```lua
---default = true
---```
---@field testingcontext? boolean
---report calls to (*testing.T).Fatal from goroutines started by a test
---
---Functions that abruptly terminate a test, such as the Fatal, Fatalf, FailNow, and
---Skip{,f,Now} methods of *testing.T, must be called from the test goroutine itself.
---This checker detects calls to these functions that occur within a goroutine
---started by the test. For example:
---
---	func TestFoo(t *testing.T) {
---	    go func() {
---	        t.Fatal("oops") // error: (*T).Fatal called from non-test goroutine
---	    }()
---	}
---
---```lua
---default = true
---```
---@field testinggoroutine? boolean
---check for common mistaken usages of tests and examples
---
---The tests checker walks Test, Benchmark, Fuzzing and Example functions checking
---malformed names, wrong signatures and examples documenting non-existent
---identifiers.
---
---Please see the documentation for package testing in golang.org/pkg/testing
---for the conventions that are enforced for Tests, Benchmarks, and Examples.
---
---```lua
---default = true
---```
---@field tests? boolean
---check for calls of (time.Time).Format or time.Parse with 2006-02-01
---
---The timeformat checker looks for time formats with the 2006-02-01 (yyyy-dd-mm)
---format. Internationally, "yyyy-dd-mm" does not occur in common calendar date
---standards, and so it is more likely that 2006-01-02 (yyyy-mm-dd) was intended.
---
---```lua
---default = true
---```
---@field timeformat? boolean
---report passing non-pointer or non-interface values to unmarshal
---
---The unmarshal analysis reports calls to functions such as json.Unmarshal
---in which the argument type is not a pointer or an interface.
---
---```lua
---default = true
---```
---@field unmarshal? boolean
---check for unreachable code
---
---The unreachable analyzer finds statements that execution can never reach
---because they are preceded by a return statement, a call to panic, an
---infinite loop, or similar constructs.
---
---```lua
---default = true
---```
---@field unreachable? boolean
---replace unsafe pointer arithmetic with function calls
---
---The unsafefuncs analyzer simplifies pointer arithmetic expressions by
---replacing them with calls to helper functions such as unsafe.Add,
---added in Go 1.17.
---
---Example:
---
---	unsafe.Pointer(uintptr(ptr) + uintptr(n))
---
---where ptr is an unsafe.Pointer, is replaced by:
---
---	unsafe.Add(ptr, n)
---
---```lua
---default = true
---```
---@field unsafefuncs? boolean
---check for invalid conversions of uintptr to unsafe.Pointer
---
---The unsafeptr analyzer reports likely incorrect uses of unsafe.Pointer
---to convert integers to pointers. A conversion from uintptr to
---unsafe.Pointer is invalid if it implies that there is a uintptr-typed
---word in memory that holds a pointer value, because that word will be
---invisible to stack copying and to the garbage collector.
---
---```lua
---default = true
---```
---@field unsafeptr? boolean
---check for unused functions, methods, etc
---
---The unusedfunc analyzer reports functions and methods that are
---never referenced outside of their own declaration.
---
---A function is considered unused if it is unexported and not
---referenced (except within its own declaration).
---
---A method is considered unused if it is unexported, not referenced
---(except within its own declaration), and its name does not match
---that of any method of an interface type declared within the same
---package.
---
---The tool may report false positives in some situations, for
---example:
---
---  - for a declaration of an unexported function that is referenced
---    from another package using the go:linkname mechanism, if the
---    declaration's doc comment does not also have a go:linkname
---    comment.
---
---    (Such code is in any case strongly discouraged: linkname
---    annotations, if they must be used at all, should be used on both
---    the declaration and the alias.)
---
---  - for compiler intrinsics in the "runtime" package that, though
---    never referenced, are known to the compiler and are called
---    indirectly by compiled object code.
---
---  - for functions called only from assembly.
---
---  - for functions called only from files whose build tags are not
---    selected in the current build configuration.
---
---Since these situations are relatively common in the low-level parts
---of the runtime, this analyzer ignores the standard library.
---See https://go.dev/issue/71686 and https://go.dev/issue/74130 for
---further discussion of these limitations.
---
---The unusedfunc algorithm is not as precise as the
---golang.org/x/tools/cmd/deadcode tool, but it has the advantage that
---it runs within the modular analysis framework, enabling near
---real-time feedback within gopls.
---
---The unusedfunc analyzer also reports unused types, vars, and
---constants. Enums--constants defined with iota--are ignored since
---even the unused values must remain present to preserve the logical
---ordering.
---
---```lua
---default = true
---```
---@field unusedfunc? boolean
---check for unused parameters of functions
---
---The unusedparams analyzer checks functions to see if there are
---any parameters that are not being used.
---
---To ensure soundness, it ignores:
---  - "address-taken" functions, that is, functions that are used as
---    a value rather than being called directly; their signatures may
---    be required to conform to a func type.
---  - exported functions or methods, since they may be address-taken
---    in another package.
---  - unexported methods whose name matches an interface method
---    declared in the same package, since the method's signature
---    may be required to conform to the interface type.
---  - functions with empty bodies, or containing just a call to panic.
---  - parameters that are unnamed, or named "_", the blank identifier.
---
---The analyzer suggests a fix of replacing the parameter name by "_",
---but in such cases a deeper fix can be obtained by invoking the
---"Refactor: remove unused parameter" code action, which will
---eliminate the parameter entirely, along with all corresponding
---arguments at call sites, while taking care to preserve any side
---effects in the argument expressions; see
---https://github.com/golang/tools/releases/tag/gopls%2Fv0.14.
---
---This analyzer ignores generated code.
---
---```lua
---default = true
---```
---@field unusedparams? boolean
---check for unused results of calls to some functions
---
---Some functions like fmt.Errorf return a result and have no side
---effects, so it is always a mistake to discard the result. Other
---functions may return an error that must not be ignored, or a cleanup
---operation that must be called. This analyzer reports calls to
---functions like these when the result of the call is ignored.
---
---The set of functions may be controlled using flags.
---
---```lua
---default = true
---```
---@field unusedresult? boolean
---check for unused variables and suggest fixes
---
---```lua
---default = true
---```
---@field unusedvariable? boolean
---checks for unused writes
---
---The analyzer reports instances of writes to struct fields and
---arrays that are never read. Specifically, when a struct object
---or an array is copied, its elements are copied implicitly by
---the compiler, and any element write to this copy does nothing
---with the original object.
---
---For example:
---
---	type T struct { x int }
---
---	func f(input []T) {
---		for i, v := range input {  // v is a copy
---			v.x = i  // unused write to field x
---		}
---	}
---
---Another example is about non-pointer receiver:
---
---	type T struct { x int }
---
---	func (t T) f() {  // t is a copy
---		t.x = i  // unused write to field x
---	}
---
---```lua
---default = true
---```
---@field unusedwrite? boolean
---check for misuses of sync.WaitGroup
---
---This analyzer detects mistaken calls to the (*sync.WaitGroup).Add
---method from inside a new goroutine, causing Add to race with Wait:
---
---	// WRONG
---	var wg sync.WaitGroup
---	go func() {
---	        wg.Add(1) // "WaitGroup.Add called from inside new goroutine"
---	        defer wg.Done()
---	        ...
---	}()
---	wg.Wait() // (may return prematurely before new goroutine starts)
---
---The correct code calls Add before starting the goroutine:
---
---	// RIGHT
---	var wg sync.WaitGroup
---	wg.Add(1)
---	go func() {
---		defer wg.Done()
---		...
---	}()
---	wg.Wait()
---
---```lua
---default = true
---```
---@field waitgroup? boolean
---replace wg.Add(1)/go/wg.Done() with wg.Go
---
---The waitgroupgo analyzer simplifies goroutine management with `sync.WaitGroup`.
---It replaces the common pattern
---
---	wg.Add(1)
---	go func() {
---		defer wg.Done()
---		...
---	}()
---
---with a single call to
---
---	wg.Go(func(){ ... })
---
---which was added in Go 1.25.
---
---```lua
---default = true
---```
---@field waitgroupgo? boolean
---detect inefficient string concatenation in uses of WriteString
---
---The writestring analyzer offers to replace a call to WriteString(x + y) by
---two calls WriteString(x); WriteString(y). This is more efficient because it
---avoids the additional memory allocation produced by string concatenation;
---instead we just write each string into the buffer directly.
---
---It explicitly looks for calls to certain well-known writers such as
---bytes.Buffer, strings.Builder and bufio.Writer. The analyzer will not suggest
---a fix for calls to, say, (*os.File).WriteString, because for certain kinds of
---file such as a UDP socket, it could split a single message into two.
---Similarly it does not offer fixes when the type of the writer is unknown (as
---in calls to io.WriteString).
---
---For example:
---
---	func f(a string, b string) string {
---		 var s strings.Builder
---		 s.WriteString(a+b)
---		 return s.String()
---	}
---
---would become:
---
---	func f(a string, b string) string {
---		var s strings.Builder
---		s.WriteString(a)
---		s.WriteString(b)
---		return s.String()
---	}
---
---```lua
---default = true
---```
---@field writestring? boolean
---report calls to yield where the result is ignored
---
---After a yield function returns false, the caller should not call
---the yield function again; generally the iterator should return
---promptly.
---
---This example fails to check the result of the call to yield,
---causing this analyzer to report a diagnostic:
---
---	yield(1) // yield may be called again (on L2) after returning false
---	yield(2)
---
---The corrected code is either this:
---
---	if yield(1) { yield(2) }
---
---or simply:
---
---	_ = yield(1) && yield(2)
---
---It is not always a mistake to ignore the result of yield.
---For example, this is a valid single-element iterator:
---
---	yield(1) // ok to ignore result
---	return
---
---It is only a mistake when the yield call that returned false may be
---followed by another call.
---
---```lua
---default = true
---```
---@field yield? boolean

---annotations specifies the various kinds of compiler
---optimization details that should be reported as diagnostics
---when enabled for a package by the "Toggle compiler
---optimization details" (`gopls.gc_details`) command.
---
---(Some users care only about one kind of annotation in their
---profiling efforts. More importantly, in large packages, the
---number of annotations can sometimes overwhelm the user
---interface and exceed the per-file diagnostic limit.)
---
---TODO(adonovan): rename this field to CompilerOptDetail.
---
---@class _.lspconfig.settings.gopls.Gopls.UiDiagnosticAnnotations
---`"bounds"` controls bounds checking diagnostics.
---
---
---```lua
---default = true
---```
---@field bounds? boolean
---`"escape"` controls diagnostics about escape choices.
---
---
---```lua
---default = true
---```
---@field escape? boolean
---`"inline"` controls diagnostics about inlining choices.
---
---
---```lua
---default = true
---```
---@field inline? boolean
---`"nil"` controls nil checks.
---
---
---```lua
---default = true
---```
---@field ["nil"]? boolean

---Configure the default Go language server ('gopls'). In most cases, configuring this section is unnecessary. See [the documentation](https://github.com/golang/tools/blob/master/gopls/doc/settings.md) for all available settings.
---@class _.lspconfig.settings.gopls.Gopls
---buildFlags is the set of flags passed on to the build system when invoked.
---It is applied to queries like `go list`, which is used when discovering files.
---The most common use is to set `-tags`.
---
---If unspecified, values of `go.buildFlags, go.buildTags` will be propagated.
---
---
---```lua
---default = {}
---```
---@field ["build.buildFlags"]? any[]
---directoryFilters can be used to exclude unwanted directories from the
---workspace. By default, all directories are included. Filters are an
---operator, `+` to include and `-` to exclude, followed by a path prefix
---relative to the workspace folder. They are evaluated in order, and
---the last filter that applies to a path controls whether it is included.
---The path prefix can be empty, so an initial `-` excludes everything.
---
---DirectoryFilters also supports the `**` operator to match 0 or more directories.
---
---Examples:
---
---Exclude node_modules at current depth: `-node_modules`
---
---Exclude node_modules at any depth: `-**/node_modules`
---
---Include only project_a: `-` (exclude everything), `+project_a`
---
---Include only project_a, but not node_modules inside it: `-`, `+project_a`, `-project_a/node_modules`
---
---
---```lua
---default = { "-**/node_modules" }
---```
---@field ["build.directoryFilters"]? any[]
---env adds environment variables to external commands run by `gopls`, most notably `go list`.
---
---@field ["build.env"]? table
---(Experimental) expandWorkspaceToModule determines which packages are considered
---"workspace packages" when the workspace is using modules.
---
---Workspace packages affect the scope of workspace-wide operations. Notably,
---gopls diagnoses all packages considered to be part of the workspace after
---every keystroke, so by setting "ExpandWorkspaceToModule" to false, and
---opening a nested workspace directory, you can reduce the amount of work
---gopls has to do to keep your workspace up to date.
---
---
---```lua
---default = true
---```
---@field ["build.expandWorkspaceToModule"]? boolean
---(Experimental) obsolete, no effect
---
---
---```lua
---default = ""
---```
---@field ["build.memoryMode"]? string
---standaloneTags specifies a set of build constraints that identify
---individual Go source files that make up the entire main package of an
---executable.
---
---A common example of standalone main files is the convention of using the
---directive `//go:build ignore` to denote files that are not intended to be
---included in any package, for example because they are invoked directly by
---the developer using `go run`.
---
---Gopls considers a file to be a standalone main file if and only if it has
---package name "main" and has a build directive of the exact form
---"//go:build tag" or "// +build tag", where tag is among the list of tags
---configured by this setting. Notably, if the build constraint is more
---complicated than a simple tag (such as the composite constraint
---`//go:build tag && go1.18`), the file is not considered to be a standalone
---main file.
---
---This setting is only supported when gopls is built with Go 1.16 or later.
---
---
---```lua
---default = { "ignore" }
---```
---@field ["build.standaloneTags"]? any[]
---templateExtensions gives the extensions of file names that are treated
---as template files. (The extension
---is the part of the file name after the final dot.)
---
---
---```lua
---default = {}
---```
---@field ["build.templateExtensions"]? any[]
---workspaceFiles configures the set of globs that match files defining the
---logical build of the current workspace. Any on-disk changes to any files
---matching a glob specified here will trigger a reload of the workspace.
---
---This setting need only be customized in environments with a custom
---GOPACKAGESDRIVER.
---
---
---```lua
---default = {}
---```
---@field ["build.workspaceFiles"]? any[]
---(Experimental) fileWatcher specifies the server-side file watching strategy used by gopls.
---
---By default, this is set to "off", meaning gopls relies exclusively on the
---language client (e.g., the editor) to send file change notifications.
---
---Available options:
---  - "off"      : Client-driven watching (default)
---  - "fsnotify" : OS-level event notifications
---  - "poll"     : Periodic directory scanning
---
---
---```lua
---default = "off"
---```
---@field fileWatcher? "fsnotify" | "off" | "poll"
---gofumpt indicates if we should run gofumpt formatting.
---
---@field ["formatting.gofumpt"]? boolean
---local is the equivalent of the `goimports -local` flag, which puts
---imports beginning with this string after third-party packages. It should
---be the prefix of the import path whose imports should be grouped
---separately.
---
---It is used when tidying imports (during an LSP Organize
---Imports request) or when inserting new ones (for example,
---during completion); an LSP Formatting request merely sorts the
---existing imports.
---
---
---```lua
---default = ""
---```
---@field ["formatting.local"]? string
---(Experimental) maxFileCacheBytes sets a soft limit on the file cache size in bytes.
---If zero, the default budget is used.
---
---The cache may temporarily use more than this amount.
---Also, this parameter limits file contents; disk block usage
---as measured by du(1) may be significantly higher.
---
---
---```lua
---default = 0
---```
---@field maxFileCacheBytes? number
---codelenses overrides the enabled/disabled state of each of gopls'
---sources of [Code Lenses](codelenses.md).
---
---Example Usage:
---
---```json5
---"gopls": {
---...
---  "codelenses": {
---    "generate": false,  // Don't show the `go generate` lens.
---  }
---...
---}
---```
---
---@field ["ui.codelenses"]? _.lspconfig.settings.gopls.Gopls.UiCodelenses
---completeFunctionCalls enables function call completion.
---
---When completing a statement, or when a function return type matches the
---expected of the expression being completed, completion may suggest call
---expressions (i.e. may include parentheses).
---
---
---```lua
---default = true
---```
---@field ["ui.completion.completeFunctionCalls"]? boolean
---(For Debugging) completionBudget is the soft latency goal for completion requests. Most
---requests finish in a couple milliseconds, but in some cases deep
---completions can take much longer. As we use up our budget we
---dynamically reduce the search scope to ensure we return timely
---results. Zero means unlimited.
---
---
---```lua
---default = "100ms"
---```
---@field ["ui.completion.completionBudget"]? string
---(Experimental) experimentalPostfixCompletions enables artificial method snippets
---such as "someSlice.sort!".
---
---
---```lua
---default = true
---```
---@field ["ui.completion.experimentalPostfixCompletions"]? boolean
---(Advanced) matcher sets the algorithm that is used when calculating completion
---candidates.
---
---
---```lua
---default = "Fuzzy"
---```
---@field ["ui.completion.matcher"]? "CaseInsensitive" | "CaseSensitive" | "Fuzzy"
---placeholders enables placeholders for function parameters or struct
---fields in completion responses.
---
---@field ["ui.completion.usePlaceholders"]? boolean
---analyses specify analyses that the user would like to enable or disable.
---A map of the names of analysis passes that should be enabled/disabled.
---A full list of analyzers that gopls uses can be found in
---[analyzers.md](https://github.com/golang/tools/blob/master/gopls/doc/analyzers.md).
---
---Example Usage:
---
---```json5
---...
---"analyses": {
---  "unreachable": false, // Disable the unreachable analyzer.
---  "unusedvariable": true  // Enable the unusedvariable analyzer.
---}
---...
---```
---
---@field ["ui.diagnostic.analyses"]? _.lspconfig.settings.gopls.Gopls.UiDiagnosticAnalyses
---analysisProgressReporting controls whether gopls sends progress
---notifications when construction of its index of analysis facts is taking a
---long time. Cancelling these notifications will cancel the indexing task,
---though it will restart after the next change in the workspace.
---
---When a package is opened for the first time and heavyweight analyses such as
---staticcheck are enabled, it can take a while to construct the index of
---analysis facts for all its dependencies. The index is cached in the
---filesystem, so subsequent analysis should be faster.
---
---
---```lua
---default = true
---```
---@field ["ui.diagnostic.analysisProgressReporting"]? boolean
---annotations specifies the various kinds of compiler
---optimization details that should be reported as diagnostics
---when enabled for a package by the "Toggle compiler
---optimization details" (`gopls.gc_details`) command.
---
---(Some users care only about one kind of annotation in their
---profiling efforts. More importantly, in large packages, the
---number of annotations can sometimes overwhelm the user
---interface and exceed the per-file diagnostic limit.)
---
---TODO(adonovan): rename this field to CompilerOptDetail.
---
---@field ["ui.diagnostic.annotations"]? _.lspconfig.settings.gopls.Gopls.UiDiagnosticAnnotations
---(Advanced) diagnosticsDelay controls the amount of time that gopls waits
---after the most recent file modification before computing deep diagnostics.
---Simple diagnostics (parsing and type-checking) are always run immediately
---on recently modified packages.
---
---This option must be set to a valid duration string, for example `"250ms"`.
---
---
---```lua
---default = "1s"
---```
---@field ["ui.diagnostic.diagnosticsDelay"]? string
---(Experimental) diagnosticsTrigger controls when to run diagnostics.
---
---
---```lua
---default = "Edit"
---```
---@field ["ui.diagnostic.diagnosticsTrigger"]? "Edit" | "Save"
---(Experimental) staticcheck configures the default set of analyses staticcheck.io.
---These analyses are documented on
---[Staticcheck's website](https://staticcheck.io/docs/checks/).
---
---The "staticcheck" option has three values:
---- false: disable all staticcheck analyzers
---- true: enable all staticcheck analyzers
---- unset: enable a subset of staticcheck analyzers
---  selected by gopls maintainers for runtime efficiency
---  and analytic precision.
---
---Regardless of this setting, individual analyzers can be
---selectively enabled or disabled using the `analyses` setting.
---
---@field ["ui.diagnostic.staticcheck"]? boolean
---(Experimental) 
---@field ["ui.diagnostic.staticcheckProvided"]? boolean
---hoverKind controls the information that appears in the hover text.
---SingleLine is intended for use only by authors of editor plugins.
---
---
---```lua
---default = "FullDocumentation"
---```
---@field ["ui.documentation.hoverKind"]? "FullDocumentation" | "NoDocumentation" | "SingleLine" | "Structured" | "SynopsisDocumentation"
---linkTarget is the base URL for links to Go package
---documentation returned by LSP operations such as Hover and
---DocumentLinks and in the CodeDescription field of each
---Diagnostic.
---
---It might be one of:
---
---* `"godoc.org"`
---* `"pkg.go.dev"`
---
---If company chooses to use its own `godoc.org`, its address can be used as well.
---
---Modules matching the GOPRIVATE environment variable will not have
---documentation links in hover.
---
---
---```lua
---default = "pkg.go.dev"
---```
---@field ["ui.documentation.linkTarget"]? string
---linksInHover controls the presence of documentation links in hover markdown.
---
---
---```lua
---default = true
---```
---@field ["ui.documentation.linksInHover"]? false | true | "gopls"
---(Experimental) moveType enables producing Move Type codeactions. The implementation
---is unfinished so we use this setting to gate its use.
---
---@field ["ui.moveType"]? boolean
---importShortcut specifies whether import statements should link to
---documentation or go to definitions.
---
---
---```lua
---default = "Both"
---```
---@field ["ui.navigation.importShortcut"]? "Both" | "Definition" | "Link"
---(Advanced) symbolMatcher sets the algorithm that is used when finding workspace symbols.
---
---
---```lua
---default = "FastFuzzy"
---```
---@field ["ui.navigation.symbolMatcher"]? "CaseInsensitive" | "CaseSensitive" | "FastFuzzy" | "Fuzzy"
---symbolScope controls which packages are searched for workspace/symbol
---requests. When the scope is "workspace", gopls searches only workspace
---packages. When the scope is "all", gopls searches all loaded packages,
---including dependencies and the standard library.
---
---
---```lua
---default = "all"
---```
---@field ["ui.navigation.symbolScope"]? "all" | "workspace"
---(Advanced) symbolStyle controls how symbols are qualified in symbol responses.
---
---Example Usage:
---
---```json5
---"gopls": {
---...
---  "symbolStyle": "Dynamic",
---...
---}
---```
---
---
---```lua
---default = "Dynamic"
---```
---@field ["ui.navigation.symbolStyle"]? "Dynamic" | "Full" | "Package"
---newGoFileHeader enables automatic insertion of the copyright comment
---and package declaration in a newly created Go file.
---
---
---```lua
---default = true
---```
---@field ["ui.newGoFileHeader"]? boolean
---(Experimental) noSemanticNumber turns off the sending of the semantic token 'number'
---
---Deprecated: Use SemanticTokenTypes["number"] = false instead. See
---golang/vscode-go#3632.
---
---@field ["ui.noSemanticNumber"]? boolean
---(Experimental) noSemanticString turns off the sending of the semantic token 'string'
---
---Deprecated: Use SemanticTokenTypes["string"] = false instead. See
---golang/vscode-go#3632
---
---@field ["ui.noSemanticString"]? boolean
---(Experimental) renameMovesSubpackages enables Rename operations on packages to
---move subdirectories of the target package.
---
---@field ["ui.renameMovesSubpackages"]? boolean
---(Experimental) semanticTokenModifiers configures the semantic token modifiers. It allows
---disabling modifiers by setting each value to false.
---By default, all modifiers are enabled.
---
---@field ["ui.semanticTokenModifiers"]? table
---(Experimental) semanticTokenTypes configures the semantic token types. It allows
---disabling types by setting each value to false.
---By default, all types are enabled.
---
---@field ["ui.semanticTokenTypes"]? table
---(Experimental) semanticTokens determines whether gopls will return a
---SemanticTokensProvider at initialization, or respond
---to requests for semantic tokens.
---
---This setting being `false` won't necessary disable the client's calls
---for semantic tokens. If you want that, it would need to be configured in
---the client. For example, in VSCode, this would disable all Go semantic
---token calls to the LSP server:
---
---```json5
---"[go]": {
---    "editor.semanticHighlighting.enabled": false,
---}
---```
---
---@field ["ui.semanticTokens"]? boolean
---(For Debugging) verboseOutput enables additional debug logging.
---
---@field verboseOutput? boolean

---@class lspconfig.settings.gopls
---@field go? _.lspconfig.settings.gopls.Go
---Configure the default Go language server ('gopls'). In most cases, configuring this section is unnecessary. See [the documentation](https://github.com/golang/tools/blob/master/gopls/doc/settings.md) for all available settings.
---@field gopls? _.lspconfig.settings.gopls.Gopls
